package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@$!`0````````````(``P`!````])L$"#0```"0SP```````#0`(``(
M`"@`'0`<``8````T````-(`$"#2`!`@``0````$```4````$`````P```#0!
M```T@00(-($$"!,````3````!`````$````!``````````"`!`@`@`0(=&D`
M`'1I```%`````!````$`````<````/`$"`#P!`A$7@``T&X```8`````$```
M`@````QP```,\`0(#/`$"!@!```8`0``!@````0````$````2`$``$B!!`A(
M@00(1````$0````$````!````%#E=&3P8P``\.,$"/#C!`C<````W`````0`
M```$````4>5T9```````````````````````````!@````0````O;&EB+VQD
M+6QI;G5X+G-O+C(```0````0`````0```$=.50```````@````8````:````
M!````!0````#````1TY5`-'MR8W6(0Q#!QF#7!^ZCY5&:OI?80```&H`````
M```````````````]```````````````U`````````"L````_````&@``````
M```?````&0```$\`````````$````%<```!+````)````&,```!?````*@``
M`#<```````````````\```!<````0```````````````7@```&@````I````
M-@````````!(````:0```#D````Q`````````#,`````````9P````````!'
M````0@``````````````8````!$```!&````%@``````````````9@```!X`
M```M````(0``````````````+P`````````F``````````````!$````````
M``<```!!````/@```#H````B````2@``````````````4P```&0````G````
M!0```#L````&````,@````````!%````````````````````3````%L`````
M````*````%@````E````0P```$T````L````````````````````````````
M``!6``````````````````````````````!1```````````````"````````
M````````````````````````````50```!(````3````````````````````
M`````$X`````````#0``````````````'````&(```!9````80`````````5
M````6@````````!=````````````````````&P````@````)`````````!0`
M```P`````````````````````````!@```````````````$```!4````````
M````````````4@```#@````=````90```````````````````"``````````
M```````````\```````````````N````#```````````````````````````
M````"@````````````````````````!0```````````````C````%P``````
M``!)``````````````````````````0````T``````````,````.````"P``
M`"4```!%````"`````@`````'!`$)4`$@C@!0`&BA@&H0````DLH!"DXHC)'
MB@0,"$4```!'````````````````````20```$L```!,`````````$T```!.
M````4````%$```!2````4P````````!4``````````````!5````5@```%D`
M`````````````%H```!<````70```%\`````````80```&,`````````````
M`&4```!F````9P````````#(U;)Q6>CM[,[>1RVCX/M)ZM/O#J?=HVLOQ9NV
MV\WCGH?YG(%6I)N6:PE#UCGRBQP-.I<+Q8D%D`T4XIXA_^0."XH05\2YG$!J
M?YI\LP&+;W^IG)MNQ=\?V7%8'+OCDGRL2^/`U634?."G`@HS8MOM>O!*:V>O
MS&9"1=7LXT?&`7U!CL7#Y3\L\MO3'?JA;&"YC?$.````````````````````
M``P#`````````````!(```"1`P`````````````2````9`(`````````````
M$@```!$``````````````"`````-!``````````````2````@@,`````````
M````$@```#T!`````````````!(````9`P`````````````2````TP``````
M````````$@```!,#`````````````!(```"O```````````````2````.`$`
M````````````$@```,,"`````````````!(```!2`P`````````````2````
MU`(`````````````$@```*$!`````````````!(```!B`P`````````````2
M````60,`````````````$@```&$!`````````````!(```#A````````````
M```2````ZP$`````````````$@```(@!`````````````!(```""`@``````
M```````2````7`(`````````````$@```/`"`````````````!(```#8`0``
M```````````2````X0(`````````````$@```.0!`````````````!(```!O
M`0`````````````2````+0``````````````(````)0"`````````````!(`
M``!I`P`````````````2````>```````````````$@```/X"````````````
M`!(```"8`P`````````````2````<`,`````````````$@```$0"````````
M`````!(````/`0`````````````2````O@``````````````$@```)8!````
M`````````!(````%`P`````````````2````VP(`````````````$@```*D"
M`````````````!(```!+`@`````````````2````Z0(`````````````$@``
M`&H``````````````!(```"[`@`````````````2````0@$`````````````
M$@```,T!`````````````!(````<`0`````````````2````B@,`````````
M````$@```/<"`````````````!(```"O`0`````````````2````/```````
M````````(````/,``````````````!(```!_`0`````````````2````F0(`
M````````````$@```'@#`````````````!(```"'```````````````2````
M4```````````````(````*$"`````````````!(````S`P`````````````2
M````*@(`````````````$@```"`#`````````````!(````^`@``````````
M```2````L@(`````````````$@```"L#`````````````!(````]`P``````
M```````2````3@$``("8!`@`````$@```'L$``"HX`0(!````!$`$``[!```
M8,\$"*T+```2``X`@@0``##,!`B?`0``$@`.`.0#``",X`0(`````!(`#P"L
M`P``8$X%"`0````A`!H`Z@,``'#)!`@%````$@`.`&L$```PX`0(6@```!(`
M#@">````,)D$"``````2````+0$``&A.!0@$````$0`:`$@$``!@\@0(````
M`!``&0!+`P``9$X%"`0````1`!H`2@0``&#R!`@`````(``9`*L#``!@3@4(
M!````"$`&@#:`P``(.`$"`4````2``X`EP0``(#)!`BE`0``$@`.``(!``!L
M3@4(`0```!$`&@"J`P``8$X%"`0````1`!H`I0,``!":!`CB`0``$@`.`+8$
M``#0S00(1````!(`#@#[`P``(,X$""0````2``X`%@0``!#?!`AW````$@`.
M`,D#``!$3@4(`````!``\?_5`P``T%X%"``````0`/'_<P(``*S@!`@$````
M$0`0`.`$```0VP0(^P,``!(`#@!5!```D,@$"-$````2``X`3@0``/2;!`@`
M````$@`.`+T!``!0E@0(`````!(````O!```8,L$"-`````2``X`P@,``$1.
M!0@`````$`#Q_R($```PRP0(+0```!(`#@#$!```D-\$"$D````2``X`CP0`
M`/#'!`@T````$@`.`/8!``!M3@4($P```!$`&@"D!```4,X$"`(!```2``X`
MD00``)B5!`@`````$@`,``!L:6)P97)L+G-O+C4N,30`7TE435]D97)E9VES
M=&5R5$U#;&]N951A8FQE`%]?9VUO;E]S=&%R=%]?`%]*=E]296=I<W1E<D-L
M87-S97,`7TE435]R96=I<W1E<E1-0VQO;F5486)L90!097)L7W-Y<U]T97)M
M`%!E<FQ?<WES7VEN:70S`%!E<FQ?<V%V95]D97-T<G5C=&]R7W@`4&5R;%]A
M=&9O<FM?;&]C:P!P97)L7V-O;G-T<G5C=`!097)L7V-R;V%K7VYO8V]N=&5X
M=`!097)L7V%V7W-H:69T`%!E<FQ?<W9?,G!V7V9L86=S`%!E<FQ?<W9?<V5T
M<'9N`%!,7V1O7W5N9'5M<`!097)L7VYE=U-6<'8`4&5R;%]N97=84U]F;&%G
M<P!03%]T:')?:V5Y`'!E<FQ?9G)E90!097)L7VUG7W-E=`!097)L7V%T9F]R
M:U]U;FQO8VL`4&5R;%]S=E]S971P=@!097)L7V=V7V9E=&-H<'8`<&5R;%]R
M=6X`4&5R;%]D;W5N=VEN9`!097)L7VYE=UA3`'!E<FQ?9&5S=')U8W0`4&5R
M;%]A=E]F971C:`!B;V]T7T1Y;F%,;V%D97(`<&5R;%]P87)S90!097)L7W-A
M9F5S>7-M86QL;V,`<&5R;%]A;&QO8P!03%]M96UO<GE?=W)A<`!L:6)D;"YS
M;RXR`&QI8FTN<V\N-@!L:6)P=&AR96%D+G-O+C``<'1H<F5A9%]G971S<&5C
M:69I8P!C;&]S90!O<&5N-C0`7U]E<G)N;U]L;V-A=&EO;@!L<V5E:S8T`')E
M860`;&EB8RYS;RXV`%])3U]S=&1I;E]U<V5D`%]?<F5G:7-T97)?871F;W)K
M`&5X:70`<W!R:6YT9@!S=')N8VUP`%]?<W1R9'5P`&-L;W-E9&ER`'-T<FYC
M<'D`7U]S=&%C:U]C:&M?9F%I;`!U;FQI;FL`;6MD:7(`<F5A;&QO8P!M96UC
M:'(`9V5T<&ED`'-T<G1O:P!S=')L96X`;65M<V5T`'-T<G-T<@!R;61I<@!M
M96UC<'D`7U]L>'-T870V-`!O<&5N9&ER`%]?>'-T870V-`!?7V-T>7!E7V)?
M;&]C`'-T9&5R<@!G971U:60`<F5A9&QI;FL`97AE8W9P`'-T<F-H<@!F<')I
M;G1F`')E861D:7(V-`!M96UM;W9E`&%C8V5S<P!S=')C;7``7U]L:6)C7W-T
M87)T7VUA:6X`7U]E;G9I<F]N`&QI8F-R>7!T+G-O+C$`7V5D871A`%]?8G-S
M7W-T87)T`%]E;F0`7U]L:6)C7V-S=5]F:6YI`'!A<E]C=7)R96YT7V5X96,`
M9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R7V-L96%N=7``<&%R7V)A
M<V5N86UE`'!A<E]D:7)N86UE`'!A<E]M:W1M<&1I<@!?7V1A=&%?<W1A<G0`
M<&%R7V-U<G)E;G1?97AE8U]P<F]C`%]?;&EB8U]C<W5?:6YI=`!?9G!?:'<`
M<&%R7VEN:71?96YV`'AS7VEN:70`<&%R7V9I;F1P<F]G`'!A<E]S971U<%]L
M:6)P871H`'!A<E]E;G9?8VQE86X`6%-?26YT97)N86QS7U!!4E]#3$5!4E-4
M04-+`%A37TEN=&5R;F%L<U]005)?0D]/5`!'3$E"0U\R+C(`1TQ)0D-?,BXP
M`$=,24)#7S(N,P!'3$E"0U\R+C,N,@!'3$E"0U\R+C0````"``(``P````(`
M`@`"``(````"```````$``(``@````(``@````````````4`!@`"`````@`"
M```````"``(````"``(``@`&``````````(``@`"``,``@````(`````````
M`@`"`````````````@`'```````"``<``P`'``,``@`"``@````!``$``0`!
M``(``0`!```````!``(``0`"``$``0````(``0`!``$``0`!``$``0`!``$`
M`0````$``0`!``$``0````$``0````$``@`:`@``$````#`````2:6D-```&
M`/8$```0````$&EI#0```P``!0````````$`!0!I`@``$``````````3:6D-
M```(``H%```0````$FEI#0``!P#V!```$````'(9:0D```4`%`4``!`````4
M:6D-```$`"`%```0````$&EI#0```@``!0```````"3Q!`@&'@``8$X%"`56
M``!D3@4(!5```&A.!0@%3@``;$X%"`55``!M3@4(!6<``#3Q!`@'`0``./$$
M"`<"```\\00(!P,``$#Q!`@'!0``1/$$"`<&``!(\00(!P<``$SQ!`@'"```
M4/$$"`<)``!4\00(!V$``%CQ!`@'"@``7/$$"`<+``!@\00(!PP``&3Q!`@'
M#0``:/$$"`<.``!L\00(!P\``'#Q!`@'$```=/$$"`<1``!X\00(!Q(``'SQ
M!`@'$P``@/$$"`<4``"$\00(!Q4``(CQ!`@'%@``C/$$"`<7``"0\00(!Q@`
M`)3Q!`@'&0``F/$$"`<:``"<\00(!QL``*#Q!`@''```I/$$"`<=``"H\00(
M!QX``*SQ!`@''P``L/$$"`<@``"T\00(!R$``+CQ!`@'(@``O/$$"`<C``#`
M\00(!R0``,3Q!`@')0``R/$$"`<F``#,\00(!R<``-#Q!`@'*```U/$$"`<I
M``#8\00(!RH``-SQ!`@'*P``X/$$"`=%``#D\00(!RP``.CQ!`@'+0``[/$$
M"`<N``#P\00(!R\``/3Q!`@',```^/$$"`<Q``#\\00(!S(```#R!`@',P``
M!/($"`<T```(\@0(!S4```SR!`@'30``$/($"`<W```4\@0(!S@``!CR!`@'
M.0``'/($"`<Z```@\@0(!SL``"3R!`@'/0``*/($"`<^```L\@0(!S\``##R
M!`@'0```-/($"`=!```X\@0(!T(``#SR!`@'0P``0/($"`=$``!5B>53@^P$
MZ`````!;@<.$6P``BY/\____A=)T!>CF`0``6%O)PP``_S4L\00(_R4P\00(
M`````/\E-/$$"&@`````Z>#_____)3CQ!`AH"````.G0_____R4\\00(:!``
M``#IP/____\E0/$$"&@8````Z;#_____)43Q!`AH(````.F@_____R5(\00(
M:"@```#ID/____\E3/$$"&@P````Z8#_____)5#Q!`AH.````.EP_____R54
M\00(:$````#I8/____\E6/$$"&A(````Z5#_____)5SQ!`AH4````.E`____
M_R5@\00(:%@```#I,/____\E9/$$"&A@````Z2#_____)6CQ!`AH:````.D0
M_____R5L\00(:'````#I`/____\E</$$"&AX````Z?#^____)73Q!`AH@```
M`.G@_O___R5X\00(:(@```#IT/[___\E?/$$"&B0````Z<#^____)8#Q!`AH
MF````.FP_O___R6$\00(:*````#IH/[___\EB/$$"&BH````Z9#^____)8SQ
M!`AHL````.F`_O___R60\00(:+@```#I</[___\EE/$$"&C`````Z6#^____
M)9CQ!`AHR````.E0_O___R6<\00(:-````#I0/[___\EH/$$"&C8````Z3#^
M____):3Q!`AHX````.D@_O___R6H\00(:.@```#I$/[___\EK/$$"&CP````
MZ0#^____);#Q!`AH^````.GP_?___R6T\00(:``!``#IX/W___\EN/$$"&@(
M`0``Z=#]____);SQ!`AH$`$``.G`_?___R7`\00(:!@!``#IL/W___\EQ/$$
M"&@@`0``Z:#]____)<CQ!`AH*`$``.F0_?___R7,\00(:#`!``#I@/W___\E
MT/$$"&@X`0``Z7#]____)=3Q!`AH0`$``.E@_?___R78\00(:$@!``#I4/W_
M__\EW/$$"&A0`0``Z4#]____)>#Q!`AH6`$``.DP_?___R7D\00(:&`!``#I
M(/W___\EZ/$$"&AH`0``Z1#]____)>SQ!`AH<`$``.D`_?___R7P\00(:'@!
M``#I\/S___\E]/$$"&B``0``Z>#\____)?CQ!`AHB`$``.G0_/___R7\\00(
M:)`!``#IP/S___\E`/($"&B8`0``Z;#\____)03R!`AHH`$``.F@_/___R4(
M\@0(:*@!``#ID/S___\E#/($"&BP`0``Z8#\____)1#R!`AHN`$``.EP_/__
M_R44\@0(:,`!``#I8/S___\E&/($"&C(`0``Z5#\____)1SR!`AHT`$``.E`
M_/___R4@\@0(:-@!``#I,/S___\E)/($"&C@`0``Z2#\____)2CR!`AHZ`$`
M`.D0_/___R4L\@0(:/`!``#I`/S___\E,/($"&CX`0``Z?#[____)33R!`AH
M``(``.G@^____R4X\@0(:`@"``#IT/O___\E//($"&@0`@``Z<#[____)4#R
M!`AH&`(``.FP^___58GE5E.#Y/"#[#"-11")1"0(C44,B40D!(U%"(D$).B<
M_?__QT0D"("8!`C'1"0$@)@$",<$)#"9!`CHD$4``(`];$X%"`!U+NBR_/__
MA<"CS%X%"`^$>P$``(D$).C]^___H6A.!0B)!"3H,/___\:```,```"A:$X%
M"(D$).@<____@(A#`P```J%H3@4(B00DZ`C___^+30@QTH/!!8"(0P,```&)
M3"0HB50D+-]L)"C8!>#C!`C=!>CC!`C9R=KIW^">#X?V````P>$"B0PDZ'G\
M__^+=0R+70C'!<1>!0@$````BQ:#^P&CP%X%",=`!)7B!`B)$+H!````QT`(
MH/($",=`#)CB!`A^#Y"+#):)3)`,@\(!.=IU\H/#`\<$F`````")1"0,H<Q>
M!0B)7"0(QT0D$`````#'1"0$,,@$"(D$).B#_?__A<")PW0VH<Q>!0B)!"3H
M4/O__[A9X00(Z,8E``"%P'0LH<Q>!0B)!"3H]?K__^@@_?__C67XB=A;7EW#
MH<Q>!0B)!"3HJOW__XG#Z[FAR%X%"(7`=`J)!"3H54,``.O!N`[A!`CH>24`
M`(7`H\A>!0ATKNOAQT0D!&U.!0C'!"0)X00(Z$K\___'!"0!````Z+[[__^0
MD#'M7HGA@^3P4%12:"#@!`AH,.`$"%%6:!":!`CHV_O___20D)"0D)"0D)"0
MN$=.!0@M1$X%"(/X!G<"\\.X`````(7`=/55B>6#[!C'!"1$3@4(_]#)PY"-
M="8`N$1.!0@M1$X%",'X`HG"P>H?`=#1^'4"\\.Z`````(72=/55B>6#[!B)
M1"0$QP0D1$X%"/_2R<.0C;0F`````(`]@$X%"`!U$U6)Y8/L".A\____Q@6`
M3@4(`<GSPV:0H0CP!`B%P'0>N`````"%P'0558GE@^P8QP0D"/`$"/_0R>EY
M____Z73___^0D)"053')5U93@>SL`@``B40D5(/`.(EL)&2)Q8E\)&"-=@"+
M=(T`BWR-!,=$S&P`````QT3,=`````")\,'@"(GZB<.)\,'@&('C``#_``G#
MB?`/K-`(B?HE`/\```G#B?`/K-`8B?XE_P```#'_"<.)\,'@"(GZB5S,:(G#
MB?#!X!B!XP``_P`)PXGP#ZS0""4`_P``#ZS^&`G#@>;_````"?.)7,QP@\$"
M@_D0#X5O____C;0DT````(V$)-`"``")]8E$)"B-=@"+7=B+3=R+19B+59PS
M70`S300S7:@S3:S'11P`````,=@QRHG&B=>)P0^L_A\!R0GQB4T8@\4(.VPD
M*'7#BTPD5(MT)%2+$8M>"(M)!(MV#(E4)""+5"14B5PD&(M<)%2)3"0DB70D
M'(M"$(M2%(M+&(M;'(E$)!"+;"00B50D%(M4)%2)3"0(BTPD((E<)`R+7"0D
MBT(@BU(DB<8#="1HB00DB50D!('&F7F"6@^LV1N+7"08B4PD*(M,)""+1"0H
M]]/!X04)R`'&(VPD&"-<)`B);"0HBT0D*(M,)!B+;"0@QT0D+`````"+?"0L
M"=B+7"0<`<:+1"08B70D*,=$)#P`````#ZS9`HM<)"3!X!Z)SHM,)`@)Q@-,
M)'")="0XBU0D.,=$)$0`````@<&9>8):(?6+="0@B>CWUB-T)!`)\(MT)"@!
MP0^L_AN+?"0HB?#!YP4)^`'!BT0D(#'_B<Z+3"0@P>`>#ZS9`HG-BTPD$`G%
MBT0D*`-,)'B);"1`BVPD*/?0@<&9>8):(=")^HE$)#"+1"0P(VPD0`GH`<&)
M\`^LT!N)1"0PB?#!X`6)1"1(BT0D,`M$)$@!P8E,)#"+1"0HBU0D+(M,)"C'
M1"0T`````,=$)"P`````#ZS0`HM4)$#!X1Z)Q0G-BTPD.(GP`XPD@````/?0
MB6PD2,=$)$P`````@<&9>8):(="+5"0TB40D*(M$)"@A]<=$)#P`````">@!
MP8M$)#`/K-`;B?J+?"0PB40D*(M$)##WU\'@!8E$)#B+1"0H"T0D.`'!B?")
M3"0H#ZS0`HGQP>$>B<:+5"0T"<Z+3"1``XPDB````(ET)#B+="0P@<&9>8):
M(WPD2"-T)#B)^(M\)"P)\(MT)"@!P0^L_AN+?"0HB?#!YP4)^`'!BT0D,#'_
MB<Z+3"0P#ZS0`L'A'HG%"<V);"1`BT0D*(M,)$B+5"0X`XPDD````/?0BVPD
M*,=$)#0`````@<&9>8):(=")1"0PBT0D,(GZ(VPD0,=$)$0`````QT0D3```
M```)Z`'!B?`/K-`;BU0D+(E$)#")\,'@!8E$)$B+1"0P"T0D2`'!BT0D*(E,
M)#"+3"0H#ZS0`HM4)$#!X1Z)Q0G-BTPD.(GP`XPDF````/?0B6PD2('!F7F"
M6B'0BU0D-(E$)"B+1"0H(?4)Z`'!BT0D,`^LT!N)^HE$)"B+1"0PP>`%B40D
M.(M$)"@+1"0X`<&)\(E,)"@/K-`"B?'!X1Z)QHM\)#`)SHM,)$`#C"2@````
MB70D.(MT)##WUXM4)#2!P9EY@EHC?"1((W0D.,=$)"P`````B?B+?"0L"?"+
M="0H`<''1"0\`````,=$)$0`````#ZS^&XM\)"B)\,=$)#0`````P><%"?@!
MP8M$)#`Q_XG.BTPD,`^LT`*+5"0XP>$>B<6+1"0H"<V+3"1(`XPDJ````(EL
M)$"+;"0H]]"!P9EY@EHAT(E$)#"+1"0PB?HC;"1`">@!P8GP#ZS0&XM4)"R)
M1"0PB?#!X`6)1"1(BT0D,`M$)$@!P8M$)"B)3"0PBTPD*`^LT`+!X1Z)Q0G-
MB?");"1(BTPD./?0BU0D0`.,)+````#'1"0L`````,=$)$P`````@<&9>8):
M(="+5"0TB40D*(M$)"@A]<=$)#P`````QT0D1``````)Z`'!BT0D,`^LT!N)
M^HM\)#")1"0HBT0D,/?7P>`%B40D.(M$)"@+1"0X`<&)\(E,)"@/K-`"B?'!
MX1Z)QHM4)#0)SHM,)$`#C"2X````B70D.(MT)#"!P9EY@EHC?"1((W0D.(GX
MBWPD+`GPBW0D*`'!#ZS^&XM\)"B)\,'G!0GX`<&+1"0P,?^)SHM,)#`/K-`"
MBU0D.,'A'HG%BT0D*`G-BTPD2`.,),````");"1`]]"!P9EY@EHAT(E$)#"+
M;"0HB?J+1"0P(VPD0,=$)#0`````QT0D3``````)Z`'!B?`/K-`;BU0D+(E$
M)#")\,'@!8E$)$B+1"0P"T0D2,=$)"P`````QT0D/``````!P8M$)"B)3"0P
MBTPD*`^LT`*+5"1`P>$>B<4)S8M,)#B)\`.,),@```#WT(EL)$B!P9EY@EHA
MT(M4)#2)1"0HBT0D*"'U">@!P8M$)#`/K-`;B?J+?"0PB40D*(M$)##WU\'@
M!8E$)#B+1"0H"T0D.`'!B?")3"0H#ZS0`HGQP>$>B<:+5"0T"<Z+3"1``XPD
MT````(ET)#B+="0P@<&9>8):(WPD2"-T)#B)^(M\)"P)\(MT)"@!P0^L_AN+
M?"0HB?#!YP4)^`'!BT0D,#'_B<Z+3"0P#ZS0`L'A'HG%"<V);"1`BT0D*(M,
M)$B+5"0X`XPDV````/?0BVPD*,=$)#0`````@<&9>8):(=")1"0PBT0D,(GZ
M(VPD0,=$)$0`````QT0D3``````)Z`'!B?`/K-`;BU0D+(E$)#")\,'@!8E$
M)$B+1"0P"T0D2`'!BT0D*(E,)#"+3"0H#ZS0`HM4)$#!X1Z)Q0G-BTPD.(GP
M`XPDX````/?0B6PD2('!F7F"6B'0BU0D-(E$)"B+1"0H(?4)Z`'!BT0D,`^L
MT!N)^HE$)"B+1"0PP>`%B40D.(M$)"@+1"0X`<&)\(E,)"@/K-`"B?'!X1Z)
MQHM\)#`)SHM,)$`#C"3H````B70D.(MT)##WUXM4)#2!P9EY@EHC?"1((W0D
M.,=$)"P`````B?B+?"0L"?"+="0H`<''1"0\`````,=$)$0`````#ZS^&XM\
M)"B)\,=$)#0`````P><%"?@!P8M$)#`Q_XG.BTPD,`^LT`*+5"0XP>$>B<6+
M1"0H"<V+3"1(`XPD\````(EL)$"+;"0H]]"!P9EY@EHAT(E$)#"+1"0PB?HC
M;"1`">@!P8GP#ZS0&XM4)"R)1"0PB?#!X`6)1"1(BT0D,`M$)$@!P8M$)"B)
M3"0PBTPD*`^LT`+!X1Z)Q0G-B?");"1(BTPD./?0BU0D0`.,)/@```#'1"0L
M`````,=$)$P`````@<&9>8):(="+5"0TB40D*(M$)"@A]<=$)#P`````QT0D
M1``````)Z`'!BT0D,`^LT!N)^HM\)#")1"0HBT0D,/?7P>`%B40D.(M$)"@+
M1"0X`<&)\(E,)"@/K-`"B?'!X1Z)QHM4)#0)SHM,)$`#C"0``0``B70D.(MT
M)#"!P9EY@EHC?"1((W0D.(GXBWPD+`GPBW0D*`'!#ZS^&XM\)"B)\,'G!0GX
M`<&+1"0P,?^)SHM,)#`/K-`"B?K!X1Z)Q8M$)"@)S8M,)$@#C"0(`0``B6PD
M0('!H>O9;C-L)#@QZ`'!B?`/K-`;B40D,(GPBU0D+,'@!8E$)$B+1"0P"T0D
M2,=$)#0`````QT0D+``````!P8M$)"B)3"0PBTPD*,=$)$P`````QT0D/```
M```/K-`"BU0D-,'A'HG%"<V+3"0X`XPD$`$``(EL)$B!P:'KV6XS;"1`B>@Q
M\`'!BT0D,`^LT!N)^HM\)"R)1"0HBT0D,,'@!8E$)#B+1"0H"T0D.`'!B?")
M3"0H#ZS0`HGQP>$>B<:+1"0P"<Z+3"1``XPD&`$``(ET)#B+5"0T@<&AZ]EN
M,W0D2#'PBW0D*`'!#ZS^&XM\)"B)\,'G!0GX`<&+1"0P,?^)SHM,)#`/K-`"
MB?K!X1Z)Q0G-B6PD0(M,)$@#C"0@`0``BT0D*,=$)#0`````@<&AZ]EN,VPD
M.,=$)$0`````QT0D3``````QZ`'!B?`/K-`;BU0D+(E$)#")\,'@!8E$)$B+
M1"0P"T0D2,=$)"P`````QT0D/``````!P8M$)"B)3"0PBTPD*`^LT`*+5"0T
MP>$>B<4)S8M,)#@#C"0H`0``B6PD2('!H>O9;C-L)$")Z#'P`<&+1"0P#ZS0
M&XGZBWPD+(E$)"B+1"0PP>`%B40D.(M$)"@+1"0X`<&)\(E,)"@/K-`"B?'!
MX1Z)QHM$)#`)SHM,)$`#C"0P`0``B70D.(M4)#2!P:'KV6XS="1(,?"+="0H
M`<$/K/X;BWPD*(GPP><%"?@!P8M$)#`Q_XG.BTPD,`^LT`*)^L'A'HG%"<V)
M;"1`BTPD2`.,)#@!``"+1"0HQT0D-`````"!P:'KV6XS;"0XQT0D1`````#'
M1"1,`````#'H`<&)\`^LT!N+5"0LB40D,(GPP>`%B40D2(M$)#`+1"1(QT0D
M+`````#'1"0\``````'!BT0D*(E,)#"+3"0H#ZS0`HM4)#3!X1Z)Q0G-BTPD
M.`.,)$`!``");"1(@<&AZ]EN,VPD0(GH,?`!P8M$)#`/K-`;B?J+?"0LB40D
M*(M$)##!X`6)1"0XBT0D*`M$)#@!P8GPB4PD*`^LT`*)\<'A'HG&BT0D,`G.
MBTPD0`.,)$@!``")="0XBU0D-('!H>O9;C-T)$@Q\(MT)"@!P0^L_AN+?"0H
MB?#!YP4)^`'!BT0D,#'_B<Z+3"0P#ZS0`HGZP>$>B<4)S8EL)$"+3"1(`XPD
M4`$``(M$)"C'1"0T`````('!H>O9;C-L)#C'1"1$`````,=$)$P`````,>@!
MP8GP#ZS0&XM4)"R)1"0PB?#!X`6)1"1(BT0D,`M$)$C'1"0L`````,=$)#P`
M`````<&+1"0HB4PD,(M,)"@/K-`"BU0D-,'A'HG%"<V+3"0X`XPD6`$``(EL
M)$B!P:'KV6XS;"1`B>@Q\`'!BT0D,`^LT!N)^HM\)"R)1"0HBT0D,,'@!8E$
M)#B+1"0H"T0D.`'!B?")3"0H#ZS0`HGQP>$>B<:+1"0P"<Z+3"1``XPD8`$`
M`(ET)#B+5"0T@<&AZ]EN,W0D2#'PBW0D*`'!#ZS^&XM\)"B)\,'G!0GX`<&+
M1"0P,?^)SHM,)#`/K-`"B?K!X1Z)Q0G-B6PD0(M,)$@#C"1H`0``BT0D*,=$
M)#0`````@<&AZ]EN,VPD.,=$)$0`````QT0D3``````QZ`'!B?`/K-`;BU0D
M+(E$)#")\,'@!8E$)$B+1"0P"T0D2,=$)"P`````QT0D/``````!P8M$)"B)
M3"0PBTPD*`^LT`*+5"0TP>$>B<4)S8M,)#@#C"1P`0``B6PD2('!H>O9;C-L
M)$")Z#'P`<&+1"0P#ZS0&XGZBWPD+(E$)"B+1"0PP>`%B40D.(M$)"@+1"0X
M`<&)\(E,)"@/K-`"B?'!X1Z)QHM$)#`)SHM,)$`#C"1X`0``B70D.(M4)#2!
MP:'KV6XS="1(,?"+="0H`<$/K/X;BWPD*(GPP><%"?@!P8M$)#`Q_XG.BTPD
M,`^LT`*)^L'A'HG%"<V);"1`BTPD2`.,)(`!``"+1"0HQT0D-`````"!P:'K
MV6XS;"0XQT0D1`````#'1"1,`````#'H`<&)\`^LT!N+5"0LB40D,(GPP>`%
MB40D2(M$)#`+1"1(QT0D+`````#'1"0\``````'!BT0D*(E,)#"+3"0H#ZS0
M`HM4)#3!X1Z)Q0G-BTPD.`.,)(@!``");"1(@<&AZ]EN,VPD0(GH,?`!P8M$
M)#`/K-`;B?J+?"0LB40D*(M$)##!X`6)1"0XBT0D*`M$)#@!P8GPB4PD*`^L
MT`*)\<'A'HG&BT0D,`G.BTPD0`.,))`!``")="0XBU0D-('!H>O9;C-T)$@Q
M\(MT)"@!P0^L_AN+?"0HB?#!YP4)^`'!BT0D,#'_B<Z+3"0P#ZS0`HGZP>$>
MB<4)S8EL)%B+3"1(`XPDF`$``(M$)"C'1"0T`````('!H>O9;C-L)#C'1"1<
M`````,=$)$0`````,>@!P8GP#ZS0&XM4)"R)1"0PB?#!X`6)1"1`BT0D,`M$
M)$#'1"0L`````,=$)#P``````<&+1"0HB4PD,(M,)"@/K-`"BU0D-,'A'HG%
M"<V+3"0X`XPDH`$``(EL)$"!P:'KV6XS;"18B>@Q\`'!BT0D,`^LT!N)^HM\
M)$")1"0HBT0D,,'@!8E$)#B+1"0H"T0D.`'!B?")3"0H#ZS0`HGQP>$>B<:+
M5"0T"<Z+3"18`XPDJ`$``(ET)#B!P=R\&X\)]R-\)#`C="1`B?B+?"0L"?"+
M="0H`<$/K/X;BWPD*(GPP><%"?@!P8M$)#`Q_XG.BTPD,`^LT`+!X1Z)Q0G-
MB6PD,(M,)$"+1"0XBU0D*`.,)+`!``#'1"1$`````,=$)#0`````@<'<O!N/
M">@AT(GZB40D0(M$)$`C;"0X">@!P8GP#ZS0&XM4)"R)1"1`B?#!X`6)1"1(
MBT0D0`M$)$C'1"0L``````'!BT0D*(E,)$"+3"0H#ZS0`HM4)$3!X1Z)Q8M$
M)#`)S8M,)#@#C"2X`0``B6PD*('!W+P;CPGH(?")1"0XBT0D."-L)#`)Z`'!
MBT0D0`^LT!N)^HE$)#B+1"1`P>`%B40D2(M$)#@+1"1(`<&)\(E,)#@/K-`"
MB?'!X1Z)QHM\)"@)SHM,)#`#C"3``0``B70D2(M4)$3'1"0\`````('!W+P;
MCPGW(WPD0"-T)"C'1"1,`````(GXBWPD/`GPBW0D.`'!QT0D-`````#'1"0L
M``````^L_AN+?"0XB?#!YP4)^`'!BT0D0#'_B<Z+3"1`#ZS0`HM4)#C!X1Z)
MQ8M$)$@)S8M,)"@#C"3(`0``B6PD,('!W+P;CPGH(=")^HE$)"B+1"0H(VPD
M2`GH`<&)\`^LT!N+5"0\B40D*(GPP>`%B40D0(M$)"@+1"1``<&+1"0XB4PD
M*(M,)#@/K-`"P>$>B<4)S8EL)#B+3"1(BT0D,`.,)-`!``"+5"0LQT0D1```
M``"!P=R\&X\)Z"'PB40D0(M$)$`C;"0PQT0D/`````#'1"1,``````GH`<&+
M1"0H#ZS0&XGZBWPD.(E$)$"+1"0HP>`%B40D2(M$)$`+1"1(`<&)\(E,)$`/
MK-`"B?'!X1Z)QHM4)"P)SHM,)#`#C"38`0``B70D2,=$)"P`````@<'<O!N/
M"?<C?"0H(W0D.(GXBWPD1`GPBW0D0`'!#ZS^&XM\)$")\,'G!0GX`<&+1"0H
M,?^)SHM,)"@/K-`"BU0D0,'A'HG%BT0D2`G-BTPD.`.,).`!``");"0H@<'<
MO!N/">@AT(GZB40D,(M$)#`C;"1(QT0D-`````#'1"0\``````GH`<&)\`^L
MT!N+5"1$B40D,(GPP>`%B40D.(M$)#`+1"0XQT0D1`````#'1"1,``````'!
MBT0D0(E,)#"+3"1`#ZS0`HM4)#3!X1Z)Q8M$)"@)S8M,)$@#C"3H`0``B6PD
M.('!W+P;CPGH(?")1"1`BT0D0"-L)"@)Z`'!BT0D,`^LT!N)^HM\)#B)1"1`
MBT0D,,'@!8E$)$B+1"1`"T0D2`'!B?")3"1`#ZS0`HGQP>$>B<:+5"0T"<Z+
M3"0H`XPD\`$``(ET)$B!P=R\&X\)]R-\)#`C="0XB?B+?"1$"?"+="1``<$/
MK/X;BWPD0(GPP><%"?@!P8M$)#`Q_XG.BTPD,`^LT`+!X1Z)Q0G-B6PD*(M,
M)#B+1"1(BU0D0`.,)/@!``#'1"0T`````,=$)"P`````@<'<O!N/">@AT(GZ
MB40D,(M$)#`C;"1(QT0D/``````)Z`'!B?`/K-`;BU0D1(E$)#")\,'@!8E$
M)#B+1"0P"T0D.`'!BT0D0(E,)#"+3"1`#ZS0`HM4)#3!X1Z)Q8M$)"@)S8M,
M)$@#C"0``@``B6PD.('!W+P;CPGH(?")1"1`BT0D0"-L)"@)Z`'!BT0D,`^L
MT!N)^HE$)$"+1"0PP>`%B40D2(M$)$`+1"1(`<&)\(E,)$`/K-`"B?'!X1Z)
MQHM\)#@)SHM,)"@#C"0(`@``B70D2(M4)#3'1"1$`````('!W+P;CPGW(WPD
M,"-T)#C'1"1,`````(GXBWPD1`GPBW0D0`'!QT0D+`````#'1"0T``````^L
M_AN+?"1`B?#!YP4)^`'!BT0D,#'_B<Z+3"0P#ZS0`HM4)$#!X1Z)Q8M$)$@)
MS8M,)#@#C"00`@``B6PD*('!W+P;CPGH(=")^HE$)#"+1"0P(VPD2`GH`<&)
M\`^LT!N+5"1$B40D,(GPP>`%B40D.(M$)#`+1"0X`<&+1"1`B4PD,(M,)$`/
MK-`"P>$>B<4)S8EL)#B+3"1(BT0D*`.,)!@"``"+5"0TQT0D1`````"!P=R\
M&X\)Z"'PB40D0(M$)$`C;"0HQT0D/`````#'1"1,``````GH`<&+1"0PQT0D
M+``````/K-`;B?J+?"0XB40D0(M$)##!X`6)1"1(BT0D0`M$)$@!P8GPB4PD
M0`^LT`*)\<'A'HG&BU0D-`G.BTPD*`.,)"`"``")="1(@<'<O!N/"?<C?"0P
M(W0D.(GXBWPD1`GPBW0D0`'!#ZS^&XM\)$")\,'G!0GX`<&+1"0P,?^)SHM,
M)#`/K-`"BU0D0,'A'HG%BT0D2`G-BTPD.`.,)"@"``");"0H@<'<O!N/">@A
MT(GZB40D,(M$)#`C;"1(QT0D-`````"+7"0TQT0D/``````)Z`'!B?`/K-`;
MBU0D1(E$)#")\,'@!8E$)#B+1"0P"T0D.,=$)$0`````QT0D3``````!P8M$
M)$")3"0PBTPD0`^LT`*+5"0TP>$>B<6+1"0H"<V+3"1(`XPD,`(``(EL)#B!
MP=R\&X\)Z"'PB40D0(M$)$`C;"0H">@!P8M$)#`/K-`;B?J+?"0XB40D0(M$
M)##!X`6)1"1(BT0D0`M$)$@!P8GPB4PD0`^LT`*)\<'A'HG&"<Z+3"0H`XPD
M.`(``(ET)$B!P=R\&X\)]R-\)#`C="0XB?B+?"1$"?"+="1``<$/K/X;BWPD
M0(GPP><%"?@!P8M$)#`Q_XG.BTPD,,'@'@^LV0*)S0G%B6PD6(M,)#B+1"1(
MBU0D0`.,)$`"``"+7"1$QT0D+`````"!P=R\&X\)Z"'0B?J)1"0HBT0D*"-L
M)$C'1"1<`````,=$)#P`````">@!P8GP#ZS0&XM4)"R)1"0HB?#!X`6)1"0P
MBT0D*`M$)##'1"0T``````'!BT0D0(E,)"B+3"1`P>`>#ZS9`HG-BTPD2`G%
M`XPD2`(``(EL)#B!P=;!8LHS;"18B>@Q\`'!BT0D*`^LT!N)^HE$)#"+1"0H
MP>`%B40D0(M$)#`+1"1``<&)\`^LT`*)3"0PB?&)QL'A'@G.B70D0(M,)%@#
MC"10`@``BT0D*(M\)#2!P=;!8LJ+5"0L,W0D.,=$)"P`````QT0D1``````Q
M\(MT)#`!P<=$)$P`````QT0D/``````/K/X;BWPD,(GPP><%"?@!P8M$)"@Q
M_XG.BTPD*`^LT`*)^L'A'HG%BT0D,`G-BTPD.`.,)%@"``");"1(@<'6P6+*
M,VPD0#'H`<&)\`^LT!N+5"0TB40D*(GPP>`%B40D.(M$)"@+1"0X`<&+1"0P
MB4PD*(M,)#`/K-`"BU0D+,'A'HG%"<V+3"1``XPD8`(``(EL)#B!P=;!8LHS
M;"1(B>@Q\`'!BT0D*`^LT!N)^HE$)#"+1"0HQT0D-`````"+?"0TQT0D1```
M``#'1"1,`````,'@!8E$)$"+1"0P"T0D0`'!B?")3"0P#ZS0`HGQP>$>B<:+
M1"0H"<Z+3"1(`XPD:`(``(ET)$"+5"0LQT0D+`````"!P=;!8LHS="0X,?"+
M="0P`<$/K/X;BWPD,(GPP><%"?@!P8M$)"@Q_XG.BTPD*`^LT`*)^L'A'HG%
MBT0D,`G-BTPD.`.,)'`"``");"1(@<'6P6+*,VPD0#'H`<&)\`^LT!N+5"0T
MB40D*(GPP>`%B40D.(M$)"@+1"0X`<&+1"0PB4PD*(M,)#`/K-`"P>$>B<4)
MS8EL)#B+3"1``XPD>`(``(M4)"S'1"0T`````('!UL%BRC-L)$C'1"0\````
M`,=$)$0`````B>@Q\`'!BT0D*,=$)$P`````#ZS0&XGZBWPD-(E$)#"+1"0H
MP>`%B40D0(M$)#`+1"1``<&)\(E,)#`/K-`"B?'!X1Z)QHM$)"@)SHM,)$@#
MC"2``@``B70D0(M4)"R!P=;!8LHS="0X,?"+="0P`<$/K/X;BWPD,(GPP><%
M"?@!P8M$)"@Q_XG.BTPD*`^LT`*)^L'A'HG%BT0D,`G-BTPD.`.,)(@"``")
M;"1(@<'6P6+*,VPD0#'H`<&)\`^LT!N)1"0HB?"+5"0TP>`%B40D.(M$)"@+
M1"0XQT0D+`````#'1"0T``````'!BT0D,(E,)"B+3"0PQT0D/`````#'1"1$
M``````^LT`*+5"0LP>$>B<4)S8M,)$`#C"20`@``B6PD.('!UL%BRC-L)$B)
MZ#'P`<&+1"0H#ZS0&XGZBWPD-(E$)#"+1"0HP>`%B40D0(M$)#`+1"1``<&)
M\(E,)#`/K-`"B?'!X1Z)QHM$)"@)SHM,)$@#C"28`@``B70D0(M4)"R!P=;!
M8LHS="0X,?"+="0P`<$/K/X;BWPD,(GPP><%"?@!P8M$)"@Q_XG.BTPD*`^L
MT`*)^L'A'HG%"<V);"1(BTPD.`.,)*`"``"+1"0PQT0D+`````"!P=;!8LHS
M;"1`QT0D3`````#'1"0\`````#'H`<&)\`^LT!N+5"0TB40D*(GPP>`%B40D
M.(M$)"@+1"0XQT0D-`````#'1"1$``````'!BT0D,(E,)"B+3"0P#ZS0`HM4
M)"S!X1Z)Q0G-BTPD0`.,)*@"``");"0X@<'6P6+*,VPD2(GH,?`!P8M$)"@/
MK-`;B?J+?"0TB40D,(M$)"C!X`6)1"1`BT0D,`M$)$`!P8GPB4PD,`^LT`*)
M\<'A'HG&BT0D*`G.BTPD2`.,)+`"``")="1`BU0D+('!UL%BRC-T)#@Q\(MT
M)#`!P0^L_AN+?"0PB?#!YP4)^`'!BT0D*#'_B<Z+3"0H#ZS0`HGZP>$>B<4)
MS8EL)$B+3"0X`XPDN`(``(M$)##'1"0L`````('!UL%BRC-L)$#'1"1,````
M`,=$)#P`````,>@!P8GP#ZS0&XM4)#2)1"0HB?#!X`6)1"0XBT0D*`M$)#C'
M1"0T`````,=$)$0``````<&+1"0PB4PD*(M,)#`/K-`"BU0D+,'A'HG%"<V+
M3"1``XPDP`(``(EL)#B!P=;!8LHS;"1(B>@Q\`'!BT0D*`^LT!N)^HM\)#2)
M1"0PBT0D*,'@!8E$)$"+1"0P"T0D0`'!B?")3"0P#ZS0`HGQP>$>B<:+1"0H
M"<Z+3"1(`XPDR`(``(ET)$"+5"0L@<'6P6+*,W0D.#'PBW0D,`'!#ZS^&XM\
M)#")\,'G!0GX`<&+1"0H,?^)SHM,)"@/K-`"B?K!X1Z)Q0G-B6PD2(M,)#@#
MC"30`@``BT0D,,=$)"P`````BUPD+('!UL%BRC-L)$#'1"1,`````,=$)#P`
M````,>@!P8GP#ZS0&XM4)#2)1"0HB?#!X`6)1"0XBT0D*`M$)#C'1"0T````
M``'!BT0D,(E,)"B+3"0P#ZS0`HGZP>$>B<6+1"1`"<T#A"38`@``B6PD,`76
MP6+*,VPD2(GI,?$!R(M,)"@/K-D;B4PD.(M,)"C!X06)3"1`BTPD.`M,)$`!
MR#';B<&)\`^LT`*+5"0LB<6+1"0HP>8>"?6);"0X#ZS0`L'J`HE$)$")5"1$
MBT0D*(M4)"R+="1(#Z3"'L'@'@.T).`"``")1"18BT0D*(E4)%R)VH'&UL%B
MRC-L)#`QZ`'&B<@/K-`;P>H;B40D*(G(B50D+(G:#Z3"!<'@!8E$)$B+1"0H
M"T0D2(E4)$P!QHGPBW0D5`-$)"")!HM$)!C'1@0`````QT8,`````,=&%```
M```!R(E&"(M$)$`+1"18`T0D$(E&$(M$)#@#1"0(B488QT8<`````(M$)#`#
M!"3'1B0`````B48@@<3L`@``6UY?7<.-M@````!55U:)QE.#["R%P(E4)!QT
M2Z%@3@4(A<")1"08=#X/M@8\/75#,=N+1"08BRB%[70KB<>0C70F`(E<)`B)
M="0$B2PDZ*C8__^%P'4'@'P=`#UT+8/'!(LOA>UUW(/$+#'`6UY?7<-FD(3`
M=+F)\X/#`0^V`SP]=`2$P'7R*?/KIXM$)!R)^2M,)!C!^0*)"(/$+(U$'0%;
M7E]=PY"-="8`@^P<C50D#.A4____@\0<PU.)PX/L&(U4)`R)V.@_____A<!T
M-HUV`*%@3@4(BU0D#(T4D(M*!(7)B0ITV8UV`(/"!(M*!(7)B0IU](U4)`R)
MV.@)____A<!US8/$&%O#5E.#[!2A:$X%"(D$).C^U___BX!P`0``BW`$H6A.
M!0B)!"3HZ-?__P^VF/@"``"A:$X%"(/C?XD$).C1U___BT`$#[=`$,'@!PG8
M9HE&`J%H3@4(B00DZ+37__^+@'`!``"+6`2A:$X%"(D$).B>U___QT0D"```
M``#'1"0$C^($"(D$).CVU?__B4,<H6A.!0B)!"3H=M?__XN`<`$``(M8!*%H
M3@4(B00DZ&#7__^+@/@#``")0R"A:$X%"(D$).A*U___BX!P`0``BU@$H6A.
M!0B)!"3H--?__S'2BX`8!@``A<!T%J%H3@4(B00DZ!O7__^+@!@&``"+4'"A
M:$X%"(E3)(D$).@"U___BX!P`0``BT`$QT`H`````*%H3@4(B00DZ.76__^+
M@'`!``"+0`3'0!@`````H6A.!0B)!"3HR-;__XN`<`$``(M8!*%H3@4(B00D
MZ++6__^+@'@!``")0RR#Q!1;7L.-=@"![)P```"%P(FT))````")QHF<)(P`
M``")O"24````B:PDF````'0%@#@`=2.+G"2,````B[0DD````(N\))0```"+
MK"28````@<2<````PXD$).B(UO__A<")QW3/B3PDZ/K5__^%P(G##X2@````
M@'L3+@^$K@```(DT)(UK$^A+U/__B2PDB40D'.@_U/__BTPD'(U$`0*)!"3H
MS]/__XEL)`R)="0(QT0D!+#@!`B)!"2)P^B5U?__C40D((E$)`B)7"0$QP0D
M`P```.B]U?__@_C_=!"+1"0P)0#P```]`$```'1HB1PDZ+#2__^)'"3H&-+_
M_XD\).A@U?__A<")PP^%9O___XVV`````(D\).BXU?__B30DZ##2___I"/__
M_XUV``^V0Q2$P`^$*O___SPN#X4^____@'L5``^$&/___^DO____D(UT)@")
MV.BI_O__ZY>-M"8`````55>)QU8QP%.)TX/L/(`Z/0^4P`'#B1PDZ%/3__^-
M5"0LB<6)^.@&_/__A<")Q@^$U````(D$).@TT___.<4/AJ0```"+3"0LP>$"
M#[8'/#T/A&H!``"$P`^$8@$``(GXZPJ-M@````"$TG0+@\`!#[80@/H]=?$I
M^(LU8$X%"(U$*`*)!"0!SNB#TO__A<")!@^$/`$``*%@3@4(BU0D+(L$D.L+
MC78`@/H]=`^#P`$/MA>#QP&$TH@0=>S&`#TQTHVT)@`````/M@P3B$P0`8/"
M`83)=?$QP(/$/%M>7UW#C;0F``````^V`X/#`8@&@\8!A,!TX`^V`X/#`8@&
M@\8!A,!UXNO/BQ5@3@4(BP*%P`^$KP```#'VC;8`````@\8!BP2RA<!U]HT$
MM0@```"+#:!.!0B%R70UB40D!(D4).BYT?__A<")1"0<HV!.!0AT?XT,M0``
M``"+1"0<QT2P!`````")="0LZ=O^__^)!"2)5"08QP6@3@4(`0```.B*T?__
MBU0D&(7`B40D''1!C0RU`````(E,)`B)5"0$B00DB4PD&.CSS___BT0D'(M,
M)!BC8$X%".N?C70F`#'`Z;+^__^X"````#'VZ5[___^X_____^G\_O__C78`
M@>P\$```B;0D,!```(UT)!S'1"0(_P\``(ET)`3'!"2VX`0(B;PD-!```(G'
MB:PD.!```(G59:$4````B80D'!```#'`B9PD+!```.@_T/__A<`/CH<```"-
M6/^`?!P<`'1UB<.)7"0(QT0D!"\```")-"3HU]'__X7`=&.A:$X%"(D$).C6
MTO__B5PD#(ET)`B)?"0$B00DZ%+2__^+A"0<$```93,%%````'51BYPD+!``
M`(NT)#`0``"+O"0T$```BZPD.!```('$/!```,.-M"8`````A=MUB8UT)@"A
M:$X%"(D$).ASTO__B6PD"(E\)`2)!"3HH\___^N?Z#S/__^-M@````"-OP``
M``!3B<.#[!BA:$X%"(D$).@]TO__B5PD!,<$)`,```"#P%R)1"0(Z#;2__^%
MP'0*@\08,<!;PXUV`*%H3@4(B00DZ`O2__^+0&PE`/```#T`0```=!RA:$X%
M"(D$).COT?__BT!L)0#P```]`*```'6^B1PDQT0D!`(```#H(-'__X7`#Y3`
M@\08#[;`6\.-=@"#[!RA:$X%"(D$).BPT?__QT0D#,7@!`C'1"0(4)8$",=$
M)`3/X`0(B00DZ"#0__^#Q!S#C;8`````C;\`````@^PLH6A.!0B)!"3H<-'_
M_XD$).BH____H6A.!0B)!"3H6]'__\=$)!0`````QT0D$(_B!`C'1"0,C^($
M",=$)`@0VP0(QT0D!.O@!`B)!"3H:]#__X/$+,.-M"8`````@>PL(```B9PD
M("```(U<)!IEH10```")A"0<(```,<")M"0D(```B;PD*"```.B-SO__QT0D
M#,'@!`C'1"0$`.$$"(D<)(E$)`CH@=#__X7`>'6-O"0;$```QT0D"``0``")
M?"0$B1PDZ.+-__^%P(G&>%2-0`&)!"3H<<[__X7`B<-T0XET)`B)?"0$B00D
MZ`O-___&!#,`BY0D'"```&4S%10```")V'4ABYPD("```(NT)"0@``"+O"0H
M(```@<0L(```PY`QV^O-Z"_-___K#9"0D)"0D)"0D)"0D)#I&____XUT)@"-
MO"<`````55=64X'L3!```&6A%````(F$)#P0```QP+@.X00(B[0D8!```(N\
M)&00``#HC_?__\=$)`0O````B30DB</H_<W__X7`="V)\K@7X00(Z)WZ__^+
ME"0\$```93,5%````(GP#X4W`0``@<1,$```6UY?7<.)-"3HY,W__XD\)(U\
M)#S'1"0$).$$"(E$)"SH_,[__XG%9I"%[72K@'T``'4%O0SA!`B%VW04B6PD
M!(D<).BIR___A<`/A)<```")+"3HF<W__X!\!?\O=1%FD(/H`8!\!?\OQD0%
M``!T\8M4)"R-1!`!/?\/```/CU7___^)="00QT0D#";A!`B);"0(QT0D!$7B
M!`B)/"3HSL[__Z%H3@4(B00DZ!'/__^)?"0$QP0D`P```(/`7(E$)`CHZL[_
M_X7`=1RA:$X%"(D$).CISO__BT!L)0#P```]`(```'0;QT0D!"3A!`C'!"0`
M````Z";.__^)Q>DG____QT0D!`$```")/"3H_\W__X7`==&)^K@7X00(Z%_Y
M__^)/"3H5\W__XG&Z;/^___H:\O__XUT)@"-O"<`````BT0D!`^V"(3)=""-
M4`'K"@^V"H/"`83)=!&`^2]U\0^V"HG0@\(!A,EU[_/#C78`4X/L&(M<)""%
MVW0\@#L`=#>)'"3H9\S__XU$`_\YPW(.ZU&0C70F`(/H`3G8=`F`."]T].LW
M9I"`."^0C70F`'5]C;8`````QP0D`@```.C,R___A<!T8&;'`"X`@\086\.-
MM@````"`."]T!X/H`3G#<O0YV'3`@^@!.<-S!8`X+W3T*=B-4`*!^@`0``!W
M)X/``8E<)`2)1"0(QP0DP$X%".BXS/__@\08N,!.!0A;PXVV`````(/$&#'`
M6\/'1"0@)N$$"(/$&%OI0,S__U=6@^PT9:$4````B40D+#'`H9SB!`B)1"0*
MH:#B!`B)1"0.H:3B!`B)1"02H:CB!`B)1"06H:SB!`B)1"0:H;#B!`B)1"0>
MH;3B!`B)1"0BH;CB!`B)1"0F#[<%O.($"&:)1"0JN"CA!`CHL?3__[@QX00(
MZ*?T__^X.>$$".B=]/__N$+A!`CHD_3__[A)X00(Z(GT__^X6>$$".A_]/__
MN`[A!`CH=?3__[AEX00(Z&OT__^X;^$$".AA]/__N'GA!`CH5_3__[@7X00(
MZ$WT__^X@^$$".A#]/__N(SA!`CH.?3__[B7X00(Z!_T__^%P'0,B<*X;^$$
M".@_]___N*CA!`CH!?3__X7`=`R)PKBZX00(Z"7W__^XQ>$$".CK\___A<!T
M+XG"N`[A!`CH"_?__[KQX00(N$GA!`CH_/;__XM$)"QE,P44````=4F#Q#1>
M7\.0N-7A!`CHKO/__X7`=!*)PKAEX00(Z,[V___KP8UT)@"-="0;O^;A!`BY
M"@```/.F=:N-5"0EN&7A!`CHJ/;__^N;Z,'(__^0H8#R!`B#^/]T!O/#C70F
M`(/L#+AEX00(Z%/S__^%P'0?#[80,<"$TG0(,<"`^C`/E<"C@/($"(/$#,.0
MC70F`#'`Z^Z-M@````"-OP````"#[!SH>,C__XD$).C0Q___A<!T#(L`@\0<
MPXVV`````#'`Z_*-M@````"-OP````!55[_]X00(5E.[\^$$"(/L7,=$)#3]
MX00(C70D/,=$)#CSX00(QT0D/`#B!`C'1"1`]N$$",=$)$3[X00(QT0D2`WB
M!`C'1"1,`````.LBD(M$)'")+"2)1"0$Z"#'__^%P'0\A=MT*HL&B=^#Q@2)
MPXGXZ'CR__^%P(G%=`6`.`!US8M4)'")^.B2]?__A=MUUH/$7%M>7UW#C;8`
M````BT0D<(D$).CDR/__B2PDB40D+.C8R/__BU0D+(U$`@*)!"3H:,C__XEL
M)!#'1"0,).$$",=$)`1%X@0(B<*+1"1PB10DB50D+(E$)`CH'LK__XM4)"R)
M^.@C]?__Z6+___^-M"8`````C;PG`````%575E.![#R!``!EH10```")A"0L
M@0``,<"X#N$$"(NL)%"!``#'1"1`).($",=$)$0,X00(QT0D2`````#'1"18
MNN$$",=$)%RSX00(QT0D8"GB!`C'1"1DT.$$",=$)&@QX@0(QT0D;`````#'
M1"1,&.($",=$)%`UX@0(QT0D5`````#H5O'__X7`=`F`.``/A<D#``#H)/[_
M_X7`B<8/A-L#```/OAZ$VW0@Z.[)__^)\HUT)@"+"/8$60AU`\8"7X/"`0^^
M&H3;=>N-?"1<N+KA!`CK"H/'!(M'_(7`="[H^?#__X7`B<-TZX`X`'3FZ`GW
M__^%P'3=B1PDZ`W(__^%P(G"=5&-M"8`````BUPD0(7;=$"`.P"_`0```'46
MZS2-="8`BUR\0(7;="B#QP&`.P!T((G8Z,'V__^%P'3EB1PDZ,7'__^%P'39
MB<+K!Y"-="8`,=*)%"2)5"0LZ!K'__^)-"2)P^@0Q___C9P#!`0``(D<).BA
MQO__BU0D+(ET)!3'1"00/N($",=$)`PFX00(B50D",=$)`1#X@0(B00DB40D
M,.A1R/__BT0D,,=$)`3``0``B00DZ#W'__^#^/\/A(0```"A:$X%"(D$).AW
MR/__QP0D`P```(/`7(E$)`B+1"0PB40D!.ALR/__A<`/A)P```"+1"0PB40D
M#(M%`,=$)`3\X@0(B40D"*%D3@4(B00DZ(#&___'1"0T`````(N4)"R!``!E
M,Q44````BT0D-`^%:`D``('$/($``%M>7UW#D(UT)@#HV\;__XL`@_@1#X1L
M____B40D$(M$)#")1"0,BT4`QT0D!,#B!`B)1"0(H61.!0B)!"3H&,;__\=$
M)#0`````ZY:-M@````"A:$X%"(D$).BKQ___BT!L)0#P```]`$````^%1/__
M_Z%H3@4(B00DZ(O'__^+<'3H<\3__SG&#X4G____H6A.!0B)!"3H;L?__XM`
M;"7_`0``/<`!```/A0?___^)'"3H(\7__XE$)#2X]N$$".C5[O__A<`/A+,!
M``")!"3H]<7__XE$)`2+10")!"3H]O;__X7`B<,/A)(!``")'"3H1,7__X/X
M`WXGC70#_+],X@0(N04```#SIG45@_@$#X0[!P``@'P#^R\/A#`'``"0Z`/[
M__^%P'4<QT0D!`````")'"3H+\7__X7`B40D.`^%00$``+KQX00(N&7A!`CH
M=/'__S';Z$W$___'1"04C^($",=$)`PFX00(QT0D!&KB!`B)1"00BT0D,(E$
M)`B+1"0TB00DZ"W&__^+="0TBWPD,.M!C78`Z$O%__^#.!%U2>@!Q/__@\,!
MQT0D&(_B!`B)7"04QT0D#";A!`B)?"0(QT0D!'CB!`B)1"00B30DZ.+%___'
M1"0$P`$``(DT).C2Q/__@_C_=*V+1"0PB00DZ('"__^+5"0TN`[A!`CHP_#_
M_XM$)#2)!"3HE_K__^G*_?__9I")!"2)1"0LZ(3Z__^+1"0LB00DZ)C$__^)
M1"0TZ:?]__^X&.($"+L!````ZPZ-=@"+1)Q,@\,!A<!T(>A`[?__A<!T[(`X
M`'3GB00DZ%_$__^%P'3;B<;IZOO__[X=X@0(Z0?\__^+70#I9O[__\=$)`P"
M````QT0D!.[____'1"0(_____XD$).CRPO__BT0D.(V4)"P!``#'1"0(!@``
M`(E4)`2)!"3H@\'__X"\)"P!````=0Z`O"0M`0``0P^$\`4``(M$)#C'1"0,
M`````,=$)`0`````QT0D"`````")!"3HE\+__\>$)+`````!(T5GQX0DM```
M``````#'A"2X````B:O-[\>$)+P`````````QX0DP````/[<NIC'A"3$````
M`````,>$),@```!V5#(0QX0DS`````````#'A"30````\.'2P\>$)-0`````
M````QX0DV`````````#'A"3<`````````,>$).``````````QX0DY```````
M``#'A"0H`0```````&:0BT0D.(V4)"P!``#'1"0(`(```(E4)`2)!"3H@<#_
M_X7`B<4/CN,!``"+C"38````B>B)[XN<)-P```#!X`.)[L'_'P'(@_L`=P0Y
MP780@X0DX`````&#E"3D`````(F$)-@```"+A"0H`0``#ZS^'<'O'0&T).``
M```1O"3D````A<#'A"3<``````````^$;`$``+I`````B>\IPCG5?@*)UXV$
M!.@```"-E"0L`0``B7PD"(E4)`2)!"3H'\#__XN$)"@!```!^(/X0(F$)"@!
M```/A2;___^-G"0L`0``*?V-A"2P`````=_HG\;__XVT)@````"#_3\/CM8`
M``")[HG[C78`BP.#[D")A"3H````BT,$B80D[````(M#"(F$)/````"+0PR)
MA"3T````BT,0B80D^````(M#%(F$)/P```"+0QB)A"0``0``BT,<B80D!`$`
M`(M#((F$)`@!``"+0R2)A"0,`0``BT,HB80D$`$``(M#+(F$)!0!``"+0S")
MA"08`0``BT,TB80D'`$``(M#.(F$)"`!``"+0SR#PT")A"0D`0``C80DL```
M`.C7Q?__@_X_#X]&____@^U`B>K!Z@:-0@'!X`;!X@8!QRG5C80DZ````(EL
M)`B)?"0$B00DZ/*^__^)K"0H`0``Z0;^__^-M@````"-O"0L`0``Z>S^__^+
M1"0XB00DZ&C"__^+A"3@````BY0DY````(N<)-@```"+M"3<````B40D.(E4
M)#R)V(GR#ZS0`X/@/XU0`8/Z.,:$!.@```"`#X^%`@``NC<````IPHV$!.D`
M``")5"0(QT0D!`````")!"3H@\#__XM4)#R-;"1TBT0D.(B<)"<!```/K-`8
MBU0D/(B$)"`!``"+1"0X#ZS0$(M4)#R(A"0A`0``BT0D.`^LT`@/ME0D.(B$
M)"(!``")V(B4)",!``")\@^LT!B)\HB$)"0!``")V`^LT!")\HB$)"4!``")
MV`^LT`B(A"0F`0``C80DL````.B*Q/__BX0DL````(N4)+0```")QHG#B=</
MK/X8B?&)U@^L\Q")UHN4)+P```"(7"1TB<.(1"1VBX0DN`````^L\PB(7"1U
MB=:(3"1SB<,/K/,8B=:(7"1WB<,/K/,0B=:+E"3$````B%PD>(G#B$0D>HN$
M),`````/K/,(B%PD>8G6B<,/K/,8B=:(7"1[B<,/K/,0B=:+E"3,````B%PD
M?(G#B$0D?HN$),@````/K/,(B%PD?8G6B<,/K/,8B=:(7"1_B<,/K/,0B=:+
ME"34````B)PD@````(G#B(0D@@```(N$)-`````/K/,(B)PD@0```(G6B<,/
MK/,8B=:(G"2#````B<,/K/,0B=:(G"2$````B<,/K/,(C;0DAP```(B<)(4`
M``")]XB$)(8```"-G"2O````#[;!Z0P```"0C70F``^V10"#Q0&)/"2#QP*)
M1"0(QT0D!&7B!`CHJK___SG?==[&A"2O`````,=$)!2/X@0(B70D$(M$)##'
M1"0,)N$$",=$)`16X@0(B40D"(M$)#2)!"3H;K___^F<^?__BVT$A>T/A,;X
M__^)+"3HUKW__X/X`P^&M?C__XUT!?R_4>($"+D%````\Z8/A9_X__^)Z^F8
M^/__NC\````IPHV$!.D```")5"0(QT0D!`````")!"3H_KW__XV$)+````#H
M@L+__XV4).@```"Y#@```#'`B=?SJ^E8_?__@+PD+@$``$$/A0+Z__^`O"0O
M`0``0P^%]/G__X"\)#`!``!(#X7F^?__@+PD,0$``$4/A=CY__^+1"0XQT0D
M#`(```#'1"0$QO___\=$)`C_____B00DZ&^\__^+1"0XC90D+`$``(E4)`3'
M1"0(*0```(D$).@`N___C90D+`$``,=$)!2/X@0(B50D$.G&_O__Z(.[__^-
M=@!55U93@^P<H6A.!0B)!"3HC+[__\:`^0(```&X2>$$".@+YO__A<!T"8`X
M,0^$E@(``.CI\/__H6A.!0B)!"3H7+[__\=$)`P+````QT0D"`$```#'1"0$
MB>($"(D$).@<O/__A<`/A+P```"+0`R#/<1>!0@!BW@8#XZI````,?:[`0``
M`.LJBT4,B40D!*'`7@4(BP28B00DZ#&Z__^%P'5UH<1>!0B#PP&#Q@$YV'YK
MH6A.!0B)!"3HX;W__\=$)`P`````B70D"(E\)`2)!"3H.;W__X7`=#V+*/9%
M"01UI:%H3@4(B00DZ+"]___'1"0,`@```,=$)`@`````B6PD!(D$).CDNO__
MZ7K___^-M"8`````H<1>!0B-4/\Y\@^$0`$``*%H3@4(B00DZ&N]___'1"0,
M!````,=$)`@!````QT0D!([B!`B)!"3H*[O__X7`B<-T-8M`#(LPH6A.!0B)
M!"3H,[W__\=$)`B0X@0(B70D!(D$).A?NO__BT,,BQCV0PI`#X48`0``H6A.
M!0B)!"3H`[W__\=$)`P$````QT0D"`$```#'1"0$E>$$"(D$).C#NO__A<")
MPW0VN!?A!`CH8^3__X7`B<8/A'$!``"+0PR+.*%H3@4(B00DZ+>\__^)="0(
MB7PD!(D$).CGN?__H6A.!0B)!"3HFKS__\:`^0(```"A:$X%"(D$).B&O/__
MQX!P!````````+@.X00(Z`+D__^%P*/(7@4(#X2=````QT0D!,`!``")!"3H
M!;O__X/X$70-A<!T"8/X_P^%>@$``(/$'%M>7UW#C78`@_@!#XZW_O__NP$`
M``!FD*%H3@4(@\,!B00DZ!B\__^)?"0$B00DZ)RX__\Y'<1>!0A_W.F'_O__
MC;0F`````*%H3@4(B00DZ.N[__^)7"0$B00DZ/^Z___IRO[__V:0@'@!``^$
M9?W__^E;_?__D*'`7@4(B00DZ&OQ__^%P*/(7@4(#X39````BT,,BSW`7@4(
MBS#V1@D$=&R+1@R)?"0$B00DZ*ZX__^)QHM##(L8]D,)!'1^BT,,B40D"*'`
M7@4(B70D#(L`QP0D=.,$"(E$)`3HW[G__XVT)@````"AP%X%"(LXBT,,BS"A
M:$X%"(D$).@_N___B?J)\.C6Y___Z8K^__^A:$X%"(D$).@DN___QT0D#`(`
M``#'1"0(`````(ET)`2)!"3H6+C__^EI____H6A.!0B)!"3H]KK__\=$)`P"
M````QT0D"`````")7"0$B00DZ"JX___I5____\<$)%#C!`CH2;G__XE$)`RA
MR%X%"(E$)`BAP%X%"(L`QP0DG.,$"(E$)`3H);G__Y"-="8`5E.#[!2+="0@
MB30DZ#_L__\/M@B$R71/C5`!B</K"Y`/M@J#P@&$R701@/DO=?$/M@J)TX/"
M`83)=>_H@.[__X7`=!V%]G09@#X`=!3'1"0$/N($"(D<).ACMO__.=AT"H/$
M%%M>PXG#Z]"#Q!2)\%M>Z8GC__^)]HV\)P````"#[!RA:$X%"(D$).@0NO__
MQT0D!/____^)!"3H<+?__Z%H3@4(B00DZ/.Y___'1"0(`````,=$)`2@P00(
MB00DZ*NY__^#Q!S#D)"0D)"0D%6)Y5/H,@```('#/Q$``(/L$(N#/`$``(E$
M)`R+11")1"0(BT4,B40D!(M%"(D$).@;M___@\006UW#BQPDPY!5B>5=PXUT
M)@"-O"<`````58GE5U93Z.#___^!P^T0``"#[!SH3[7__XV[W/[__XV#V/[_
M_RG'P?\"A?]T)#'VBT40B40D"(M%#(E$)`2+10B)!"3_E+/8_O__@\8!.?YR
MWH/$'%M>7UW#D)!5B>53@^P$Z`````!;@<.0$```65O)PP```````P````$`
M`@`E<R\E<P`O<')O8R]S96QF+V5X90!P97)L>'-I+F,`1'EN84QO861E<CHZ
M8F]O=%]$>6YA3&]A9&5R`$EN=&5R;F%L<SHZ4$%2.CI"3T]4`"]P<F]C+R5I
M+R5S`"X`4$%27U1%35``4$%27U!23T=.04U%`#H`+P!015),-4Q)0@!015),
M3$E"`%!%4DPU3U!4`%!%4DQ)3P!005)?24Y)5$E!3$E:140`4$%27U-005=.
M140`4$%27T-,14%.`%!!4E]$14)51P!005)?0T%#2$4`4$%27T%21T,`4$%2
M7T%21U9?,`!005)?1TQ/0D%,7T1%0E5'`%!!4E]'3$]"04Q?5$U01$E2`%!!
M4E]435!$25(`4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`4$%2
M7T-,14%./0`Q`$Q)0E!!5$@`1%E,1%],24)205)97U!!5$@`4TA,24)?4$%4
M2`!54T52`%-94U1%30`O=&UP`%1%35!$25(`5$U0`%5315).04U%`'!A<BT`
M)7,E<R5S)7,`<&%R;``N<&%R`"5S)7-C86-H92TE<R5S`"4P,G@`)7,E<W1E
M;7`M)74E<P`E<R5S=&5M<"TE=2TE=25S`$%21U8`&`!P97)L`"UE`"TM``!?
M7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@(``````E<SH@8W)E871I
M;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE
M:2D*```E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP
M;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*``!5
M;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0`````E<SH@97AE8W5T
M:6]N(&]F("5S(&9A:6QE9"`H97)R;F\])6DI"@``)7,Z(&-R96%T:6]N(&]F
M('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\]
M)6DI"@``````````````````@/___\]!`1L#.]@````:````T+'___0````@
MMO__5`4``/"X__\8`0``L-S__U@!``!0W?__K`$``&#=___$`0``L-W__^@!
M```@W___%`(``(#@__]``@``8.+__X`"``!PX___K`(```#D___8`@``0.3_
M__`"``"@Y/__"`,``(#E__\P`P``D.7__T0#``!`Y___A`,``'#G__^8`P``
M0.C__]@#``#@Z?__"`0``##J__\D!```8.K__T`$``!PZ___@`0``"#W___$
M!```(/O__P0%``"@^___/`4``!0``````````7I2``%\"`$;#`0$B`$``"``
M```<````U+#__U`$````#@A&#@Q*#PMT!'@`/QH[*C(D(CP```!`````T+?_
M_[HC````00X(A0)##@R'`T$.$(8$00X4@P5&#H`&`ZDC#A1!PPX00<8.#$''
M#@A!Q0X$``!0````@````%#;__^;`````$$."(4"00X,AP-!#A"&!$,.%(,%
M0PY``E8*#A1#PPX00<8.#$''#@A!Q0X$0PMJ#A1%PPX00<8.#$''#@A!Q0X$
M```4````U````)S;__\0`````$,.($P.!``@````[````)3;__]0`````$$.
M"(,"10X@`D@."$'##@0````H````$`$``,#;__]M`0```$$."(8"00X,@P-#
M#B`#90$.#$'##@A!Q@X$`"@````\`0``!-W__UD!````1@Z@`4F&!%>#!8<#
MA0)I"L7'QL,.!$$+````/````&@!```XWO__W0$```!!#@B%`D$.#(<#0PX0
MA@1##A2#!44.4`+/"@X40<,.$$'&#@Q!QPX(0<4.!$@+`"@```"H`0``V-__
M_P0!````1@[`($>&!%Z'`TF%`EB#!0*$"L7'QL,.!$@+*````-0!``"\X/__
MC0````!!#@B#`D4.(&L*#@A#PPX$1`L"4`X(1,,.!``4``````(``"#A__\T
M`````$,.('`.!``4````&`(``$CA__]9`````$,.,`)5#@0D````,`(``)#A
M___1`````$8.L$!'@P1AA@.'`@*8"L?&PPX$0@L`$````%@"``!(XO__!0``
M```````\````;`(``$3B__^E`0```$$."(4"00X,AP-!#A"&!$$.%(,%1@[@
M(`)E"@X40<,.$$'&#@Q!QPX(0<4.!$$+$````*P"``"TX___+0`````````\
M````P`(``-#C___0`````$$."(,"0PX@`EP*#@A!PPX$1PL"0PH."$;##@1'
M"T,*#@A#PPX$00M+#@A!PPX$+``````#``!@Y/__GP$```!!#@B'`D$.#(8#
M0PY``T\!"@X,0<8."$''#@1""P``&````#`#``#0Y?__1`````!3#A!G"@X$
M1@L``!@```!,`P``!.;__R0`````0PX@5@H.!$<+```\````:`,``!CF__\"
M`0```$$."(4"00X,AP-&#A"&!$$.%(,%2`YP`H0*#A1!PPX00<8.#$''#@A!
MQ0X$1PL`0````*@#``#HYO__K0L```!!#@B%`D$.#(<#00X0A@1!#A2#!48.
MT(("`SP""@X40<,.$$'&#@Q!QPX(0<4.!$8+```\````[`,``%3R___[`P``
M`$$."(4"00X,AP-!#A"&!$$.%(,%0PXP`UD""@X40<,.$$'&#@Q!QPX(0<4.
M!$0+-````"P$```4]O__=P````!!#@B&`D$.#(,#0PX@`E\*#@Q!PPX(0<8.
M!$$+1PX,0\,."$'&#@04````9`0``%SV__])`````$,.(`)%#@0H````?`0`
M`,2P___B`0```$$."(4"0@T%2(8#@P0#>P$*PT'&0<4,!`1!"P``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````+"<!`B0G`0(``````$````!`````0````4"```!````$`(```$`
M```:`@```0```&D"```!````M`,```P```"8E00(#0```(S@!`@9`````/`$
M"!L````$````&@````3P!`@<````!`````0```",@00(]?[_;\"$!`@%````
MN(P$"`8````8A@0("@```"H%```+````$````!4``````````P```"CQ!`@"
M````(`(``!0````1````%P```'B3!`@1````2),$"!(````P````$P````@`
M``#^__]ON)($"/___V\"````\/__;^*1!`@`````````````````````````
M````````````````````````````````````````````#/`$"```````````
MUI4$".:5!`CVE00(!I8$"!:6!`@FE@0(-I8$"$:6!`A6E@0(9I8$"':6!`B&
ME@0(EI8$"*:6!`BVE@0(QI8$"-:6!`CFE@0(]I8$"`:7!`@6EP0()I<$"#:7
M!`A&EP0(5I<$"&:7!`AVEP0(AI<$"):7!`BFEP0(MI<$",:7!`C6EP0(YI<$
M"/:7!`@&F`0(%I@$"":8!`@VF`0(1I@$"%:8!`AFF`0(=I@$"(:8!`B6F`0(
MII@$"+:8!`C&F`0(UI@$".:8!`CVF`0(!ID$"!:9!`@FF00(-ID$"$:9!`A6
MF00(9ID$"':9!`B&F00(EID$"*:9!`BVF00(QID$"-:9!`CFF00(]ID$"`::
M!`@`````````````````````````````````````````````````````````
M``````````````````````#_____````````````````````````````````
M`````",A+W5S<B]B:6XO<&5R;`IE=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@
M("U3("0P("1[,2LB)$`B?2<*("`@(&EF(#`[(",@;F]T(')U;FYI;F<@=6YD
M97(@<V]M92!S:&5L;`H*<&%C:V%G92!?7W!A<E]P;#L*"B,@+2TM(%1H:7,@
M<V-R:7!T(&UU<W0@;F]T('5S92!A;GD@;6]D=6QE<R!A="!C;VUP:6QE('1I
M;64@+2TM"B,@=7-E('-T<FEC=#L*"B-L:6YE(#$U.`H*;7D@*"1P87)?=&5M
M<"P@)'!R;V=N86UE+"!`=&UP9FEL92D["D5.1"![(&EF("@D14Y6>U!!4E]#
M3$5!3GTI('L*("`@(')E<75I<F4@1FEL93HZ5&5M<#L*("`@(')E<75I<F4@
M1FEL93HZ0F%S96YA;64["B`@("!R97%U:7)E($9I;&4Z.E-P96,["B`@("!M
M>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP
M*3L*("`@(&]U=',H<7%[4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")]
M*3L*("`@($9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R
M;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PH@("`@<FUD:7(@)'!A<E]T
M96UP.PH@("`@(R!$;VXG="!R96UO=F4@=&]P9&ER(&)E8V%U<V4@=&AI<R!C
M875S97,@82!R86-E('=I=&@@;W1H97(@87!P<PH@("`@(R!T:&%T(&%R92!T
M<GEI;F<@=&\@<W1A<G0N"@H@("`@:68@*"UD("1P87)?=&5M<"`F)B`D7D\@
M;F4@)TU35VEN,S(G*2!["B`@("`@("`@(R!3;VUE=&AI;F<@=V5N="!W<F]N
M9R!U;FQI;FMI;F<@=&AE('1E;7!O<F%R>2!D:7)E8W1O<GDN("!4:&ES"B`@
M("`@("`@(R!T>7!I8V%L;'D@:&%P<&5N<R!O;B!P;&%T9F]R;7,@=&AA="!D
M:7-A;&QO=R!U;FQI;FMI;F<@<VAA<F5D"B`@("`@("`@(R!L:6)R87)I97,@
M86YD(&5X96-U=&%B;&5S('1H870@87)E(&EN('5S92X@56YL:6YK('=I=&@@
M82!B86-K9W)O=6YD"B`@("`@("`@(R!S:&5L;"!C;VUM86YD('-O('1H92!F
M:6QE<R!A<F4@;F\@;&]N9V5R(&EN('5S92!B>2!T:&ES('!R;V-E<W,N"B`@
M("`@("`@(R!$;VXG="!D;R!A;GET:&EN9R!O;B!7:6YD;W=S(&)E8V%U<V4@
M;W5R('!A<F5N="!P<F]C97-S('=I;&P*("`@("`@("`C('1A:V4@8V%R92!O
M9B!C;&5A;FEN9R!T:&EN9W,@=7`N"@H@("`@("`@(&UY("1T;7`@/2!N97<@
M1FEL93HZ5&5M<"@*("`@("`@("`@("`@5$5-4$Q!5$4@/3X@)W1M<%A86%A8
M)RP*("`@("`@("`@("`@1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE
M*"1T;W!D:7(I+`H@("`@("`@("`@("!3549&25@@/3X@)RYC;60G+`H@("`@
M("`@("`@("!53DQ)3DL@/3X@,"P*("`@("`@("`I.PH*("`@("`@("!P<FEN
M="`D=&UP("(C(2]B:6XO<V@*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@
M9&\*("`@<FT@+7)F("<D<&%R7W1E;7`G"B`@(&EF(%L@7"$@+60@)R1P87)?
M=&5M<"<@73L@=&AE;@H@("`@("`@8G)E86L*("`@9FD*("`@<VQE97`@,0H@
M("!X/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R(@+B`D=&UP+3YF:6QE;F%M
M92`N("(G"B(["B`@("`@("`@("`@(&-H;6]D(#`W,#`L)'1M<"T^9FEL96YA
M;64["B`@("`@("`@;7D@)&-M9"`]("1T;7`M/F9I;&5N86UE("X@)R`^+V1E
M=B]N=6QL(#(^)C$@)B<["B`@("`@("`@8VQO<V4@)'1M<#L*("`@("`@("!S
M>7-T96TH)&-M9"D["B`@("`@("`@;W5T<RAQ<2A3<&%W;F5D(&)A8VMG<F]U
M;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("D*("`@("`@("`@("`@
M("X@)'1M<"T^9FEL96YA;64I.PH@("`@?0I]('T*"D)%1TE.('L*("`@($EN
M=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI0
M05(Z.D)/3U0["@H@("`@979A;"!["@I?<&%R7VEN:71?96YV*"D["@II9B`H
M97AI<W1S("1%3E9[4$%27T%21U9?,'T@86YD("1%3E9[4$%27T%21U9?,'T@
M*2!["B`@("!`05)'5B`](&UA<"`D14Y6>R)005)?05)'5E\D7R)]+"`H,2`N
M+B`D14Y6>U!!4E]!4D=#?2`M(#$I.PH@("`@)#`@/2`D14Y6>U!!4E]!4D=6
M7S!].PI]"F5L<V4@>PH@("`@9F]R("AK97ES("5%3E8I('L*("`@("`@("!D
M96QE=&4@)$5.5GLD7WT@:68@+UY005)?05)'5E\O.PH@("`@?0I]"@IM>2`D
M<75I970@/2`A)$5.5GM005)?1$5"54=].PH*(R!F:7@@)'!R;V=N86UE(&EF
M(&EN=F]K960@9G)O;2!0051("FUY("5#;VYF:6<@/2`H"B`@("!P871H7W-E
M<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*("`@(%]E
M>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@
M/R`G+F5X92<@.B`G)RDL"B`@("!?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>
M35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PH*7W-E=%]P<F]G;F%M92@I
M.PI?<V5T7W!A<E]T96UP*"D["@HC($UA9VEC('-T<FEN9R!C:&5C:VEN9R!A
M;F0@97AT<F%C=&EN9R!B=6YD;&5D(&UO9'5L97,@>WM["FUY("@D<W1A<G1?
M<&]S+"`D9&%T85]P;W,I.PI["B`@("!L;V-A;"`D4TE'>U]?5T%23E]??2`]
M('-U8B![?3L*"B`@("`C($-H96-K(&9I;&4@='EP92P@9V5T('-T87)T(&]F
M(&1A=&$@<V5C=&EO;B![>WL*("`@(&]P96X@7T9(+"`G/"<L("1P<F]G;F%M
M92!O<B!L87-T.PH@("`@8FEN;6]D92A?1D@I.PH*("`@(&UY("1B=68["B`@
M("!S965K(%]&2"P@+3@L(#(["B`@("!R96%D(%]&2"P@)&)U9BP@.#L*("`@
M(&QA<W0@=6YL97-S("1B=68@97$@(EQN4$%2+G!M7&XB.PH*("`@('-E96L@
M7T9(+"`M,3(L(#(["B`@("!R96%D(%]&2"P@)&)U9BP@-#L*("`@('-E96L@
M7T9(+"`M,3(@+2!U;G!A8VLH(DXB+"`D8G5F*2P@,CL*("`@(')E860@7T9(
M+"`D8G5F+"`T.PH*("`@("1D871A7W!O<R`]("AT96QL(%]&2"D@+2`T.PH@
M("`@(R!]?7T*"B`@("`C($5X=')A8W1I;F<@96%C:"!F:6QE(&EN=&\@;65M
M;W)Y('M[>PH@("`@;7D@)7)E<75I<F5?;&ES=#L*("`@('=H:6QE("@D8G5F
M(&5Q(")&24Q%(BD@>PH@("`@("`@(')E860@7T9(+"`D8G5F+"`T.PH@("`@
M("`@(')E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*"B`@("`@
M("`@;7D@)&9U;&QN86UE(#T@)&)U9CL*("`@("`@("!O=71S*'%Q*%5N<&%C
M:VEN9R!F:6QE("(D9G5L;&YA;64B+BXN*2D["B`@("`@("`@;7D@)&-R8R`]
M("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U
M;F1E9CL*("`@("`@("!M>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^
M(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["@H@("`@("`@(')E860@7T9(+"`D
M8G5F+"`T.PH@("`@("`@(')E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D
M8G5F*3L*"B`@("`@("`@:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@
M+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["B`@("`@("`@("`@(&UY("@D;W5T
M+"`D9FEL96YA;64I(#T@7W1E;7!F:6QE*"1E>'0L("1C<F,I.PH@("`@("`@
M("`@("!I9B`H)&]U="D@>PH@("`@("`@("`@("`@("`@8FEN;6]D92@D;W5T
M*3L*("`@("`@("`@("`@("`@('!R:6YT("1O=70@)&)U9CL*("`@("`@("`@
M("`@("`@(&-L;W-E("1O=70["B`@("`@("`@("`@("`@("!C:&UO9"`P-S4U
M+"`D9FEL96YA;64["B`@("`@("`@("`@('T*("`@("`@("`@("`@)%!!4CHZ
M2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PH@("`@
M("`@("`@("`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D
M9G5L;&YA;64["B`@("`@("`@?0H@("`@("`@(&5L<VEF("@@)&9U;&QN86UE
M(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0?2`I
M('L*("`@("`@("`@("`@(R!S:&]U;&0@8F4@;6]V960@=&\@7W1E;7!F:6QE
M*"D*("`@("`@("`@("`@;7D@)&9I;&5N86UE(#T@(B1%3E9[4$%27U1%35!]
M+R1B87-E;F%M921E>'0B.PH@("`@("`@("`@("!O=71S*")32$Q)0CH@)&9I
M;&5N86UE7&XB*3L*("`@("`@("`@("`@;W!E;B!M>2`D;W5T+"`G/B<L("1F
M:6QE;F%M92!O<B!D:64@)"$["B`@("`@("`@("`@(&)I;FUO9&4H)&]U="D[
M"B`@("`@("`@("`@('!R:6YT("1O=70@)&)U9CL*("`@("`@("`@("`@8VQO
M<V4@)&]U=#L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@
M("1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2`]"B`@("`@("`@("`@("1005(Z
M.DAE879Y.CI-;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PH@("`@("`@("`@
M("`@("`@8G5F(#T^("1B=68L"B`@("`@("`@("`@("`@("!C<F,@/3X@)&-R
M8RP*("`@("`@("`@("`@("`@(&YA;64@/3X@)&9U;&QN86UE+`H@("`@("`@
M("`@("!].PH@("`@("`@('T*("`@("`@("!R96%D(%]&2"P@)&)U9BP@-#L*
M("`@('T*("`@(",@?7U]"@H@("`@;&]C86P@0$E.0R`]("AS=6(@>PH@("`@
M("`@(&UY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*"B`@("`@("`@<F5T=7)N
M(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PH*("`@("`@("!M>2`D9FEL
M96YA;64@/2!D96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?2!\?"!D;R![
M"B`@("`@("`@("`@(&UY("1K97D["B`@("`@("`@("`@(&9O<F5A8V@@*&ME
M>7,@)7)E<75I<F5?;&ES="D@>PH@("`@("`@("`@("`@("`@;F5X="!U;FQE
M<W,@+UQ1)&UO9'5L95Q%)"\["B`@("`@("`@("`@("`@("`D:V5Y(#T@)%\[
M(&QA<W0["B`@("`@("`@("`@('T*("`@("`@("`@("`@9&5L971E("1R97%U
M:7)E7VQI<W1[)&ME>7T@:68@9&5F:6YE9"@D:V5Y*3L*("`@("`@("!](&]R
M(')E='5R;CL*"B`@("`@("`@)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1F
M:6QE;F%M92\D;6]D=6QE(CL*"B`@("`@("`@:68@*"1%3E9[4$%27T-,14%.
M?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*("`@("`@("`@("`@
M;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`D(3L*("`@
M("`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@("`@("!P<FEN="`D9F@@
M)&9I;&5N86UE+3Y[8G5F?3L*("`@("`@("`@("`@<V5E:R@D9F@L(#`L(#`I
M.PH@("`@("`@("`@("!R971U<FX@)&9H.PH@("`@("`@('T*("`@("`@("!E
M;'-E('L*("`@("`@("`@("`@;7D@*"1O=70L("1N86UE*2`](%]T96UP9FEL
M92@G+G!M)RP@)&9I;&5N86UE+3Y[8W)C?2D["B`@("`@("`@("`@(&EF("@D
M;W5T*2!["B`@("`@("`@("`@("`@("!B:6YM;V1E*"1O=70I.PH@("`@("`@
M("`@("`@("`@<')I;G0@)&]U="`D9FEL96YA;64M/GMB=69].PH@("`@("`@
M("`@("`@("`@8VQO<V4@)&]U=#L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!O<&5N(&UY("1F:"P@)SPG+"`D;F%M92!O<B!D:64@)"$["B`@("`@("`@
M("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@("`@<F5T=7)N("1F:#L*("`@
M("`@("!]"@H@("`@("`@(&1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A
M;FYO="!F:6YD("1M;V1U;&4A7&XB.PH@("`@?2P@0$E.0RD["@H@("`@(R!.
M;W<@;&]A9"!A;&P@8G5N9&QE9"!F:6QE<R![>WL*"B`@("`C(&EN:71I86QI
M>F4@<VAA<F5D(&]B:F5C="!P<F]C97-S:6YG"B`@("!R97%U:7)E(%A33&]A
M9&5R.PH@("`@<F5Q=6ER92!005(Z.DAE879Y.PH@("`@<F5Q=6ER92!#87)P
M.CI(96%V>3L*("`@(')E<75I<F4@17AP;W)T97(Z.DAE879Y.PH@("`@4$%2
M.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PH*("`@(",@;F]W(&QE="=S
M('1R>2!G971T:6YG(&AE;'!E<B!M;V1U;&5S(&9R;VT@=VET:&EN"B`@("!R
M97%U:7)E($E/.CI&:6QE.PH*("`@(",@;&]A9"!R97-T(&]F('1H92!G<F]U
M<"!I;@H@("`@=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E
M<75I<F5?;&ES="E;,%TI('L*("`@("`@("`C;&]C86P@)$E.0WLG0W=D+G!M
M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH@("`@("`@('5N
M;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.
M+RD@>PH@("`@("`@("`@("`C(')E<75I<F4@;6]D=6QE<RP@9&\@;W1H97(@
M97AE8W5T86)L92!F:6QE<PH@("`@("`@("`@("!I9B`H)&9I;&5N86UE(#U^
M("]<+G!M8S\D+VDI('L*("`@("`@("`@("`@("`@(')E<75I<F4@)&9I;&5N
M86UE.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<V4@>PH@("`@("`@
M("`@("`@("`@(R!3:VEP($%C=&EV95-T871E)W,@<VET96-U<W1O;6EZ92YP
M;"!F:6QE.@H@("`@("`@("`@("`@("`@9&\@)&9I;&5N86UE('5N;&5S<R`D
M9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["B`@("`@("`@("`@
M('T*("`@("`@("!]"B`@("`@("`@9&5L971E("1R97%U:7)E7VQI<W1[)&9I
M;&5N86UE?3L*("`@('T*"B`@("`C('U]?0H*("`@(&QA<W0@=6YL97-S("1B
M=68@97$@(E!+7#`P,UPP,#0B.PH@("`@)'-T87)T7W!O<R`]("AT96QL(%]&
M2"D@+2`T.PI]"B,@?7U]"@HC($%R9W5M96YT('!R;V-E<W-I;F<@>WM["FUY
M($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE
M7VYA;64I.PH*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I
M>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"@HD<75I970@
M/2`P('5N;&5S<R`D14Y6>U!!4E]$14)51WT["B,@1&]N)W0@<W=A;&QO=R!A
M<F=U;65N=',@9F]R(&-O;7!I;&5D(&5X96-U=&%B;&5S('=I=&AO=70@+2UP
M87(M;W!T:6]N<PII9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M
M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*("`@(&UY("5D:7-T7V-M9"`]
M('%W*`H@("`@("`@('`@("!B;&EB7W1O7W!A<@H@("`@("`@(&D@("!I;G-T
M86QL7W!A<@H@("`@("`@('4@("!U;FEN<W1A;&Q?<&%R"B`@("`@("`@<R`@
M('-I9VY?<&%R"B`@("`@("`@=B`@('9E<FEF>5]P87(*("`@("D["@H@("`@
M(R!I9B!T:&4@87!P(&ES(&EN=F]K960@87,@(F%P<&YA;64@+2UP87(M;W!T
M:6]N<R`M+7)E=7-E(%!23T=204T@0%!23T=?05)'5B(L"B`@("`C('5S92!T
M:&4@87!P('1O(')U;B!T:&4@9VEV96X@<&5R;"!C;V1E(&EN<W1E860@;V8@
M86YY=&AI;F<@9G)O;2!T:&4*("`@(",@87!P(&ET<V5L9B`H8G5T('-T:6QL
M('-E="!U<"!T:&4@;F]R;6%L(&%P<"!E;G9I<F]N;65N="!A;F0@0$E.0RD*
M("`@(&EF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["B`@
M("`@("`@<VAI9G0@0$%21U8["B`@("`@("`@)$5.5GM005)?05!07U)%55-%
M?2`]('-H:69T($!!4D=6.PH@("`@?0H@("`@96QS92![(",@;F]R;6%L('!A
M<FP@8F5H879I;W5R"@H@("`@("`@(&UY($!A9&1?=&]?:6YC.PH@("`@("`@
M('=H:6QE("A`05)'5BD@>PH@("`@("`@("`@("`D05)'5ELP72`]?B`O7BTH
M6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PH*("`@("`@("`@("`@
M:68@*"0Q(&5Q("=))RD@>PH@("`@("`@("`@("`@("`@<'5S:"!`861D7W1O
M7VEN8RP@)#(["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q
M(&5Q("=-)RD@>PH@("`@("`@("`@("`@("`@979A;"`B=7-E("0R(CL*("`@
M("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)T$G*2!["B`@
M("`@("`@("`@("`@("!U;G-H:69T($!P87)?87)G<RP@)#(["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=/)RD@>PH@("`@("`@
M("`@("`@("`@)&]U="`]("0R.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&5L<VEF("@D,2!E<2`G8B<I('L*("`@("`@("`@("`@("`@("1B=6YD;&4@
M/2`G<VET92<["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q
M(&5Q("=")RD@>PH@("`@("`@("`@("`@("`@)&)U;F1L92`]("=A;&PG.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G<2<I('L*
M("`@("`@("`@("`@("`@("1Q=6EE="`](#$["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@96QS:68@*"0Q(&5Q("=,)RD@>PH@("`@("`@("`@("`@("`@
M;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92`B6%A8.B!#86YN;W0@;W!E
M;B!L;V<Z("0A(CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H
M)#$@97$@)U0G*2!["B`@("`@("`@("`@("`@("`D8V%C:&5?;F%M92`]("0R
M.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!S:&EF="A`05)'5BD["@H@
M("`@("`@("`@("!I9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*("`@
M("`@("`@("`@("`@(&1E;&5T92`D14Y6>R=005)?5$5-4"=].PH@("`@("`@
M("`@("`@("`@:6YI=%]I;F,H*3L*("`@("`@("`@("`@("`@(')E<75I<F4@
M4$%2.CI$:7-T.PH@("`@("`@("`@("`@("`@)GLB4$%2.CI$:7-T.CHD8VUD
M(GTH*2!U;FQE<W,@0$%21U8["B`@("`@("`@("`@("`@("`F>R)005(Z.D1I
M<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PH@("`@("`@("`@("`@("`@97AI
M=#L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@=6YS:&EF="!`
M24Y#+"!`861D7W1O7VEN8SL*("`@('T*?0H*(R!86%@@+2T@861D("TM<&%R
M+61E8G5G('-U<'!O<G0A"@HC('U]?0H*(R!/=71P=70@;6]D92`H+4\I(&AA
M;F1L:6YG('M[>PII9B`H)&]U="D@>PH@("`@>PH@("`@("`@("-L;V-A;"`D
M24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>3R!N92`G35-7:6XS,B<[
M"B`@("`@("`@<F5Q=6ER92!)3SHZ1FEL93L*("`@("`@("!R97%U:7)E($%R
M8VAI=F4Z.EII<#L*("`@('T*"B`@("!M>2`D<&%R(#T@<VAI9G0H0$%21U8I
M.PH@("`@;7D@)'II<#L*"@H@("`@:68@*&1E9FEN960@)'!A<BD@>PH@("`@
M("`@(&]P96X@;7D@)&9H+"`G/"<L("1P87(@;W(@9&EE(")#86YN;W0@9FEN
M9"`G)'!A<B<Z("0A(CL*("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@
M8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*"B`@("`@("`@)'II<"`]($%R8VAI
M=F4Z.EII<"T^;F5W.PH@("`@("`@("@@)'II<"T^<F5A9$9R;VU&:6QE2&%N
M9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*("`@
M("`@("`@("`@;W(@9&EE(")296%D("<D<&%R)R!E<G)O<CH@)"$B.PH@("`@
M?0H*"B`@("!M>2`E96YV(#T@9&\@>PH@("`@("`@(&EF("@D>FEP(&%N9"!M
M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B`@("`@
M("`@("`@("1M971A(#U^(',O+BI><&%R.B0O+VUS.PH@("`@("`@("`@("`D
M;65T82`]?B!S+UY<4RXJ+R]M<SL*("`@("`@("`@("`@)&UE=&$@/7X@+UX@
M("A;7CI=*RDZ("@N*RDD+VUG.PH@("`@("`@('T*("`@('T["@H@("`@(R!/
M<&5N(&EN<'5T(&%N9"!O=71P=70@9FEL97,@>WM["B`@("!L;V-A;"`D+R`]
M(%PT.PH*("`@(&EF("AD969I;F5D("1P87(I('L*("`@("`@("!O<&5N(%!!
M4BP@)SPG+"`D<&%R(&]R(&1I92`B)"$Z("1P87(B.PH@("`@("`@(&)I;FUO
M9&4H4$%2*3L*("`@("`@("!D:64@(B1P87(@:7,@;F]T(&$@4$%2(&9I;&4B
M('5N;&5S<R`\4$%2/B!E<2`B4$M<,#`S7#`P-"(["B`@("!]"@H@("`@0W)E
M871E4&%T:"@D;W5T*2`["B`@("`*("`@(&UY("1F:"`]($E/.CI&:6QE+3YN
M97<H"B`@("`@("`@)&]U="P*("`@("`@("!)3SHZ1FEL93HZ3U]#4D5!5"@I
M('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I
M+`H@("`@("`@(#`W-S<L"B`@("`I(&]R(&1I92`D(3L*("`@(&)I;FUO9&4H
M)&9H*3L*"B`@("`D+R`]("AD969I;F5D("1D871A7W!O<RD@/R!<)&1A=&%?
M<&]S(#H@=6YD968["B`@("!S965K(%]&2"P@,"P@,#L*("`@(&UY("1L;V%D
M97(@/2!S8V%L87(@/%]&2#X["B`@("!I9B`H(21%3E9[4$%27U9%4D)!5$E-
M?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*("`@("`@("!R
M97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*("`@("`@("!005(Z.D9I
M;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1L;V%D97(L("0P*0H@("`@
M?0H@("`@9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N=BD@>PH@("`@
M("`@(&UY("1V86P@/2`D96YV>R1K97E](&]R(&YE>'0["B`@("`@("`@)'9A
M;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\["B`@("`@("`@;7D@
M)&UA9VEC(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B.PH@("`@
M("`@(&UY("1S970@/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(])'9A;"(["B`@
M("`@("`@)&QO861E<B`]?B!S>R1M86=I8R@@*RE]>PH@("`@("`@("`@("`D
M;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL96YG=&@H)#$I("T@;&5N9W1H*"1S
M970I*2D*("`@("`@("!]96<["B`@("!]"B`@("`D9F@M/G!R:6YT*"1L;V%D
M97(I.PH@("`@)"\@/2!U;F1E9CL*("`@(",@?7U]"@H@("`@(R!7<FET92!B
M=6YD;&5D(&UO9'5L97,@>WM["B`@("!I9B`H)&)U;F1L92D@>PH@("`@("`@
M(')E<75I<F4@4$%2.CI(96%V>3L*("`@("`@("!005(Z.DAE879Y.CI?:6YI
M=%]D>6YA;&]A9&5R*"D["B`@("`@("`@:6YI=%]I;F,H*3L*"B`@("`@("`@
M<F5Q=6ER95]M;V1U;&5S*"D["@H@("`@("`@(&UY($!I;F,@/2!S;W)T('L*
M("`@("`@("`@("`@;&5N9W1H*"1B*2`\/3X@;&5N9W1H*"1A*0H@("`@("`@
M('T@9W)E<"!["B`@("`@("`@("`@("$O0E-$4$%.+PH@("`@("`@('T@9W)E
M<"!["B`@("`@("`@("`@("@D8G5N9&QE(&YE("=S:71E)RD@;W(*("`@("`@
M("`@("`@*"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*
M("`@("`@("`@("`@("1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP
M?2D["B`@("`@("`@?2!`24Y#.PH*("`@("`@("`C($9I;&4@97AI<W1S('1E
M<W0@861D960@=&\@9FEX(%)4(",T,3<Y,#H*("`@("`@("`C($9U;FYY+"!N
M;VXM97AI<W1I;F<@96YT<GD@:6X@7SPN+BXN875T;R]#;VUP<F5S<R]287<O
M6FQI8B]A=71O<W!L:70N:7@N"B`@("`@("`@(R!4:&ES(&ES(&$@8F%N9"UA
M:60@9FEX('=I=&@@;F\@9&5E<&5R(&=R87-P(&]F('1H92!I<W-U92X*("`@
M("`@("`C(%-O;65B;V1Y('!L96%S92!G;R!T:')O=6=H('1H92!P86EN(&]F
M('5N9&5R<W1A;F1I;F<@=VAA="=S(&AA<'!E;FEN9RP*("`@("`@("`C($D@
M9F%I;&5D+B`M+2!3=&5F9F5N"B`@("`@("`@;7D@)69I;&5S.PH@("`@("`@
M("]>7SPH+BLI)"\@86YD("UE("0Q(&%N9"`D9FEL97-[)#%]*RL@9F]R(&ME
M>7,@)3HZ.PH@("`@("`@("1F:6QE<WLD7WTK*R!F;W(@=F%L=65S("5)3D,[
M"@H@("`@("`@(&UY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E
M>'1].PH@("`@("`@(&UY("5W<FET=&5N.PH*("`@("`@("!F;W)E86-H("AS
M;W)T(&ME>7,@)69I;&5S*2!["B`@("`@("`@("`@(&UY("@D;F%M92P@)&9I
M;&4I.PH*("`@("`@("`@("`@9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["B`@
M("`@("`@("`@("`@("!I9B`H)&YA;64@/2`D4$%2.CI(96%V>3HZ1G5L;$-A
M8VAE>R1??2D@>PH@("`@("`@("`@("`@("`@("`@("1F:6QE(#T@)%\["B`@
M("`@("`@("`@("`@("`@("`@;&%S=#L*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@(&5L<VEF("@O7BA<421D:7)<15PO*"XJ6UY#8UTI*5Q:
M+VDI('L*("`@("`@("`@("`@("`@("`@("`H)&9I;&4L("1N86UE*2`]("@D
M,2P@)#(I.PH@("`@("`@("`@("`@("`@("`@(&QA<W0["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("!E;'-I9B`H;2%>+VQO861E<B];7B]=
M*R\H+BI;7D-C72E<6B$I('L*("`@("`@("`@("`@("`@("`@("!I9B`H;7D@
M)')E9B`]("1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD,7TI('L*("`@("`@
M("`@("`@("`@("`@("`@("`@*"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I
M.PH@("`@("`@("`@("`@("`@("`@("`@("!L87-T.PH@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("`@("!E;'-I9B`H+68@(B1D:7(O
M)#$B*2!["B`@("`@("`@("`@("`@("`@("`@("`@("@D9FEL92P@)&YA;64I
M(#T@*"(D9&ER+R0Q(BP@)#$I.PH@("`@("`@("`@("`@("`@("`@("`@("!L
M87-T.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@;F5X="!U;FQE<W,@9&5F:6YE
M9"`D;F%M92!A;F0@;F]T("1W<FET=&5N>R1N86UE?2LK.PH@("`@("`@("`@
M("!N97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?
M97AT7$4D+SL*("`@("`@("`@("`@;W5T<R@@:F]I;B`B(BP*("`@("`@("`@
M("`@("`@('%Q*%!A8VMI;F<@(BDL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M
M97T@.B`D9FEL92P*("`@("`@("`@("`@("`@('%Q*"(N+BXI"B`@("`@("`@
M("`@("D["@H@("`@("`@("`@("!M>2`D8V]N=&5N=#L*("`@("`@("`@("`@
M:68@*')E9B@D9FEL92DI('L*("`@("`@("`@("`@("`@("1C;VYT96YT(#T@
M)&9I;&4M/GMB=69].PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<V4@
M>PH@("`@("`@("`@("`@("`@;W!E;B!&24Q%+"`G/"<L("1F:6QE(&]R(&1I
M92`B0V%N)W0@;W!E;B`D9FEL93H@)"$B.PH@("`@("`@("`@("`@("`@8FEN
M;6]D92A&24Q%*3L*("`@("`@("`@("`@("`@("1C;VYT96YT(#T@/$9)3$4^
M.PH@("`@("`@("`@("`@("`@8VQO<V4@1DE,13L*"B`@("`@("`@("`@("`@
M("!005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1C;VYT96YT
M+"`D9FEL92D*("`@("`@("`@("`@("`@("`@("!I9B`A)$5.5GM005)?5D52
M0D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["@H@("`@
M("`@("`@("`@("`@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA
M<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["B`@("`@("`@("`@('T*
M"B`@("`@("`@("`@(&]U=',H<7$H5W)I='1E;B!A<R`B)&YA;64B*2D["B`@
M("`@("`@("`@("1F:"T^<')I;G0H(D9)3$4B*3L*("`@("`@("`@("`@)&9H
M+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI*3L*("`@("`@
M("`@("`@)&9H+3YP<FEN="AS<')I;G1F*`H@("`@("`@("`@("`@("`@(B4P
M.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL
M("1N86UE"B`@("`@("`@("`@("DI.PH@("`@("`@("`@("`D9F@M/G!R:6YT
M*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2D["B`@("`@("`@("`@("1F
M:"T^<')I;G0H)&-O;G1E;G0I.PH@("`@("`@('T*("`@('T*("`@(",@?7U]
M"@H@("`@(R!.;W<@=W)I=&4@;W5T('1H92!005(@86YD(&UA9VEC('-T<FEN
M9W,@>WM["B`@("`D>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I(&EF("1Z
M:7`["@H@("`@)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L
M(#0P.PH@("`@:68@*"$D8V%C:&5?;F%M92!A;F0@;7D@)&UT:6UE(#T@*'-T
M870H)&]U="DI6SE=*2!["B`@("`@("`@;7D@)&-T>"`](&5V86P@>R!R97%U
M:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*("`@("`@
M("`@("`@?'P@979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z
M.E-(03$M/FYE=R!]"B`@("`@("`@("`@('Q\(&5V86P@>R!R97%U:7)E($1I
M9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["@H@("`@("`@(",@5V]R
M:V%R;W5N9"!F;W(@8G5G(&EN($1I9V5S=#HZ4TA!(#4N,S@@86YD(#4N,SD*
M("`@("`@("!M>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!
M.CI615)324].('T@?'P@,#L*("`@("`@("!I9B`H)'-H85]V97)S:6]N(&5Q
M("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2!["B`@("`@("`@
M("`@("1C='@M/F%D9&9I;&4H)&]U="P@(F(B*2!I9B`H)&-T>"D["B`@("`@
M("`@?0H@("`@("`@(&5L<V4@>PH@("`@("`@("`@("!I9B`H)&-T>"!A;F0@
M;W!E;BAM>2`D9F@L("(\)&]U="(I*2!["B`@("`@("`@("`@("`@("!B:6YM
M;V1E*"1F:"D["B`@("`@("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1F:"D[
M"B`@("`@("`@("`@("`@("!C;&]S92@D9F@I.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("`D8V%C:&5?;F%M92`]("1C='@@/R`D8W1X+3YH
M97AD:6=E<W0@.B`D;71I;64["B`@("!]"B`@("`D8V%C:&5?;F%M92`N/2`B
M7#`B('@@*#0Q("T@;&5N9W1H("1C86-H95]N86UE*3L*("`@("1C86-H95]N
M86UE("X](")#04-(12(["B`@("`D9F@M/G!R:6YT*"1C86-H95]N86UE*3L*
M("`@("1F:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D
M;&]A9&5R*2DI.PH@("`@)&9H+3YP<FEN="@B7&Y005(N<&U<;B(I.PH@("`@
M)&9H+3YC;&]S93L*("`@(&-H;6]D(#`W-34L("1O=70["B`@("`C('U]?0H*
M("`@(&5X:70["GT*(R!]?7T*"B,@4')E<&%R92`D<')O9VYA;64@:6YT;R!0
M05(@9FEL92!C86-H92![>WL*>PH@("`@;&%S="!U;FQE<W,@9&5F:6YE9"`D
M<W1A<G1?<&]S.PH*("`@(%]F:7A?<')O9VYA;64H*3L*"B`@("`C($YO=R!L
M;V%D('1H92!005(@9FEL92!A;F0@<'5T(&ET(&EN=&\@4$%2.CI,:6)#86-H
M92![>WL*("`@(')E<75I<F4@4$%2.PH@("`@4$%2.CI(96%V>3HZ7VEN:71?
M9'EN86QO861E<B@I.PH*"B`@("!["B`@("`@("`@(VQO8V%L("1)3D-[)T-W
M9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL*("`@("`@
M("!R97%U:7)E($9I;&4Z.D9I;F0["B`@("`@("`@<F5Q=6ER92!!<F-H:79E
M.CI::7`["B`@("!]"B`@("!M>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<[
M"B`@("!M>2`D9F@@/2!)3SHZ1FEL92T^;F5W.PH@("`@)&9H+3YF9&]P96XH
M9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE("(D(3H@)$`B.PH@("`@)'II<"T^
M<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E
M.CI::7`Z.D%:7T]+*"D@;W(@9&EE("(D(3H@)$`B.PH*("`@('!U<V@@0%!!
M4CHZ3&EB0V%C:&4L("1Z:7`["B`@("`D4$%2.CI,:6)#86-H97LD<')O9VYA
M;65](#T@)'II<#L*"B`@("`D<75I970@/2`A)$5.5GM005)?1$5"54=].PH@
M("`@;W5T<RAQ<2A<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB
M*2D["@H@("`@:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U
M;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"B`@("`@("`@9F]R96%C:"!M>2`D
M;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*("`@("`@("`@("`@;F5X="!I
M9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*("`@("`@("`@("`@;7D@)&UE;6)E
M<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64["B`@("`@("`@("`@(&YE>'0@
M=6YL97-S("1M96UB97)?;F%M92`]?B!M>PH@("`@("`@("`@("`@("`@7@H@
M("`@("`@("`@("`@("`@+S]S:&QI8B\*("`@("`@("`@("`@("`@("@_.B1#
M;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PH@("`@("`@("`@("`@("`@*#\Z
M)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PH@("`@("`@("`@("`@("`@
M*%M>+UTK*0H@("`@("`@("`@("`@("`@)`H@("`@("`@("`@("!]>#L*("`@
M("`@("`@("`@;7D@)&5X=')A8W1?;F%M92`]("0Q.PH@("`@("`@("`@("!M
M>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]4
M14U0?2P@)&5X=')A8W1?;F%M92D["B`@("`@("`@("`@(&EF("@M9B`D9&5S
M=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I
M*2!["B`@("`@("`@("`@("`@("!O=71S*'%Q*%-K:7!P:6YG("(D;65M8F5R
M7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE
M(BDI.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@;W5T
M<RAQ<2A%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE
M(BDI.PH@("`@("`@("`@("`@("`@)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA
M;65D*"1D97-T7VYA;64I.PH@("`@("`@("`@("`@("`@8VAM;V0H,#4U-2P@
M)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*("`@("`@("`@("`@?0H@
M("`@("`@('T*("`@('T*("`@(",@?7U]"GT*(R!]?7T*"B,@268@=&AE<F4G
M<R!N;R!M86EN+G!L('1O(')U;BP@<VAO=R!U<V%G92![>WL*=6YL97-S("@D
M4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["B`@("!D:64@/#P@(BXB('5N
M;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=
M(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R86TN<&P@70H@("`@
M("`@)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@H@("`@)$5.
M5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'
M5BD["GT*(R!]?7T*"G-U8B!#<F5A=&50871H('L*("`@(&UY("@D;F%M92D@
M/2!`7SL*("`@(`H@("`@<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*("`@(&UY
M("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF
M:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*("`@(`H@("`@<F5Q=6ER92!&
M:6QE.CI0871H.PH@("`@"B`@("!&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I
M('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]
M"@IS=6(@<F5Q=6ER95]M;V1U;&5S('L*("`@("-L;V-A;"`D24Y#>R=#=V0N
M<&TG?2`](%]?1DE,15]?(&EF("1>3R!N92`G35-7:6XS,B<["@H@("`@<F5Q
M=6ER92!L:6(["B`@("!R97%U:7)E($1Y;F%,;V%D97(["B`@("!R97%U:7)E
M(&EN=&5G97(["B`@("!R97%U:7)E('-T<FEC=#L*("`@(')E<75I<F4@=V%R
M;FEN9W,["B`@("!R97%U:7)E('9A<G,["B`@("!R97%U:7)E($-A<G`["B`@
M("!R97%U:7)E($-A<G`Z.DAE879Y.PH@("`@<F5Q=6ER92!%<G)N;SL*("`@
M(')E<75I<F4@17AP;W)T97(Z.DAE879Y.PH@("`@<F5Q=6ER92!%>'!O<G1E
M<CL*("`@(')E<75I<F4@1F-N=&P["B`@("!R97%U:7)E($9I;&4Z.E1E;7`[
M"B`@("!R97%U:7)E($9I;&4Z.E-P96,["B`@("!R97%U:7)E(%A33&]A9&5R
M.PH@("`@<F5Q=6ER92!#;VYF:6<["B`@("!R97%U:7)E($E/.CI(86YD;&4[
M"B`@("!R97%U:7)E($E/.CI&:6QE.PH@("`@<F5Q=6ER92!#;VUP<F5S<SHZ
M6FQI8CL*("`@(')E<75I<F4@07)C:&EV93HZ6FEP.PH@("`@<F5Q=6ER92!0
M05(["B`@("!R97%U:7)E(%!!4CHZ2&5A=GD["B`@("!R97%U:7)E(%!!4CHZ
M1&ES=#L*("`@(')E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PH@("`@
M<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PH@("`@<F5Q=6ER
M92!A='1R:6)U=&5S.PH@("`@979A;"![(')E<75I<F4@0W=D('T["B`@("!E
M=F%L('L@<F5Q=6ER92!7:6XS,B!].PH@("`@979A;"![(')E<75I<F4@4V-A
M;&%R.CI5=&EL('T["B`@("!E=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII
M<#HZ0G5R<W0@?3L*("`@(&5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M
M961#87!T=7)E('T["B`@("!E=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I
M<F4@4&5R;$E/.CIS8V%L87(@?3L*?0H*(R!4:&4@0R!V97)S:6]N(&]F('1H
M:7,@8V]D92!A<'!E87)S(&EN(&UY;&1R+VUK=&UP9&ER+F,*(R!4:&ES(&-O
M9&4@86QS;R!L:79E<R!I;B!005(Z.E-E='5P5&5M<"!A<R!S971?<&%R7W1E
M;7!?96YV(0IS=6(@7W-E=%]P87)?=&5M<"!["B`@("!I9B`H9&5F:6YE9"`D
M14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2![
M"B`@("`@("`@)'!A<E]T96UP(#T@)#$["B`@("`@("`@<F5T=7)N.PH@("`@
M?0H*("`@(&9O<F5A8V@@;7D@)'!A=&@@*`H@("`@("`@("AM87`@)$5.5GLD
M7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI
M+`H@("`@("`@('%W*"!#.EQ<5$5-4"`O=&UP("X@*0H@("`@*2!["B`@("`@
M("`@;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD
M("UW("1P871H.PH@("`@("`@(&UY("1U<V5R;F%M93L*("`@("`@("!M>2`D
M<'=U:60["B`@("`@("`@(R!D;V5S(&YO="!W;W)K(&5V97)Y=VAE<F4Z"B`@
M("`@("`@979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE
M9"`D/CM].PH*("`@("`@("!I9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA
M;64I("D@>PH@("`@("`@("`@("`D=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN
M3F%M93L*("`@("`@("!]"B`@("`@("`@96QS:68@*&1E9FEN960@)'!W=6ED
M*2!["B`@("`@("`@("`@("1U<V5R;F%M92`]("1P=W5I9#L*("`@("`@("!]
M"B`@("`@("`@96QS92!["B`@("`@("`@("`@("1U<V5R;F%M92`]("1%3E9[
M55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["B`@("`@("`@
M?0H@("`@("`@("1U<V5R;F%M92`]?B!S+UQ7+U\O9SL*"B`@("`@("`@;7D@
M)'-T;7!D:7(@/2`B)'!A=&@D0V]N9FEG>U]D96QI;7UP87(M)'5S97)N86UE
M(CL*("`@("`@("!M:V1I<B`D<W1M<&1I<BP@,#<U-3L*("`@("`@("!I9B`H
M(21%3E9[4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE(#T@*'-T870H)'!R;V=N
M86UE*2E;.5TI('L*("`@("`@("`@("`@;W!E;B`H;7D@)&9H+"`B/"(N("1P
M<F]G;F%M92D["B`@("`@("`@("`@('-E96L@)&9H+"`M,3@L(#(["B`@("`@
M("`@("`@('-Y<W)E860@)&9H+"!M>2`D8G5F+"`V.PH@("`@("`@("`@("!I
M9B`H)&)U9B!E<2`B7#!#04-(12(I('L*("`@("`@("`@("`@("`@('-E96L@
M)&9H+"`M-3@L(#(["B`@("`@("`@("`@("`@("!S>7-R96%D("1F:"P@)&)U
M9BP@-#$["B`@("`@("`@("`@("`@("`D8G5F(#U^(',O7#`O+V<["B`@("`@
M("`@("`@("`@("`D<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M
M(B`N("1B=68["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS92!["B`@
M("`@("`@("`@("`@("!M>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T
M.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0H@("`@("`@("`@("`@("`@
M("`@('Q\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI3
M2$$Q+3YN97<@?0H@("`@("`@("`@("`@("`@("`@('Q\(&5V86P@>R!R97%U
M:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["@H@("`@("`@
M("`@("`@("`@(R!7;W)K87)O=6YD(&9O<B!B=6<@:6X@1&EG97-T.CI32$$@
M-2XS."!A;F0@-2XS.0H@("`@("`@("`@("`@("`@;7D@)'-H85]V97)S:6]N
M(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["B`@("`@
M("`@("`@("`@("!I9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA
M7W9E<G-I;VX@97$@)S4N,SDG*2!["B`@("`@("`@("`@("`@("`@("`@)&-T
M>"T^861D9FEL92@D<')O9VYA;64L(")B(BD@:68@*"1C='@I.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@96QS92!["B`@("`@("`@("`@
M("`@("`@("`@:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1P<F]G;F%M
M92(I*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&)I;FUO9&4H)&9H*3L*
M("`@("`@("`@("`@("`@("`@("`@("`@)&-T>"T^861D9FEL92@D9F@I.PH@
M("`@("`@("`@("`@("`@("`@("`@("!C;&]S92@D9F@I.PH@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@
M("`D<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("@@)&-T
M>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM92`I.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&-L;W-E*"1F:"D["B`@("`@("`@?0H@("`@("`@(&5L
M<V4@>PH@("`@("`@("`@("`D14Y6>U!!4E]#3$5!3GT@/2`Q.PH@("`@("`@
M("`@("`D<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]=&5M<"TD)"(["B`@
M("`@("`@?0H*("`@("`@("`D14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PH@
M("`@("`@(&UK9&ER("1S=&UP9&ER+"`P-S4U.PH@("`@("`@(&QA<W0["B`@
M("!]"@H@("`@)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-4'T@86YD
M("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0H*<W5B(%]T96UP9FEL92![
M"B`@("!M>2`H)&5X="P@)&-R8RD@/2!`7SL*("`@(&UY("@D9F@L("1F:6QE
M;F%M92D["@H@("`@)&9I;&5N86UE(#T@(B1P87)?=&5M<"\D8W)C)&5X="([
M"@H@("`@:68@*"1%3E9[4$%27T-,14%.?2D@>PH@("`@("`@('5N;&EN:R`D
M9FEL96YA;64@:68@+64@)&9I;&5N86UE.PH@("`@("`@('!U<V@@0'1M<&9I
M;&4L("1F:6QE;F%M93L*("`@('T*("`@(&5L<V4@>PH@("`@("`@(')E='5R
M;B`H=6YD968L("1F:6QE;F%M92D@:68@*"UR("1F:6QE;F%M92D["B`@("!]
M"@H@("`@;W!E;B`D9F@L("<^)RP@)&9I;&5N86UE(&]R(&1I92`D(3L*("`@
M(&)I;FUO9&4H)&9H*3L*("`@(')E='5R;B@D9F@L("1F:6QE;F%M92D["GT*
M"B,@<V%M92!C;V1E(&QI=F5S(&EN(%!!4CHZ4V5T=7!0<F]G;F%M93HZ<V5T
M7W!R;V=N86UE"G-U8B!?<V5T7W!R;V=N86UE('L*("`@(&EF("AD969I;F5D
M("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^
M("\H+BLI+RD@>PH@("`@("`@("1P<F]G;F%M92`]("0Q.PH@("`@?0H*("`@
M("1P<F]G;F%M92!\?#T@)#`["@H@("`@:68@*"1%3E9[4$%27U1%35!](&%N
M9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B`@
M("`@("`@)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P
M<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PH@("`@?0H*("`@(&EF
M("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)$-O
M;F9I9WM?9&5L:6U]*2`^/2`P*2!["B`@("`@("`@:68@*&]P96X@;7D@)&9H
M+"`G/"<L("1P<F]G;F%M92D@>PH@("`@("`@("`@("!R971U<FX@:68@+7,@
M)&9H.PH@("`@("`@('T*("`@("`@("!I9B`H+7,@(B1P<F]G;F%M921#;VYF
M:6=[7V5X97TB*2!["B`@("`@("`@("`@("1P<F]G;F%M92`N/2`D0V]N9FEG
M>U]E>&5].PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H@("`@?0H*
M("`@(&9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)$-O;F9I9WMP871H7W-E
M<'U<12\L("1%3E9[4$%42'TI('L*("`@("`@("!N97AT(&EF(&5X:7-T<R`D
M14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*("`@
M("`@("`D9&ER(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<120O+SL*("`@("`@
M("`H*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE
M)$-O;F9I9WM?97AE?2(I+"!L87-T*0H@("`@("`@("`@("!I9B`M<R`B)&1I
M<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB.PH@("`@
M("`@("@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA
M;64B*2P@;&%S="D*("`@("`@("`@("`@:68@+7,@(B1D:7(D0V]N9FEG>U]D
M96QI;7TD<')O9VYA;64B.PH@("`@?0I]"@IS=6(@7V9I>%]P<F]G;F%M92![
M"B`@("`D,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345].PH@
M("`@:68@*&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`\(#`I
M('L*("`@("`@("`D<')O9VYA;64@/2`B+B1#;VYF:6=[7V1E;&EM?21P<F]G
M;F%M92(["B`@("!]"@H@("`@(R!86%@@+2!H86-K('1O(&UA:V4@4%=$('=O
M<FL*("`@(&UY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D
M.CIG971C=V0H*0H@("`@("`@("`@("`@("`@.B`H*&1E9FEN960@)E=I;C,R
M.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PH@("`@8VAO
M;7`H)'!W9"D["B`@("`D<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421#;VYF
M:6=[7V1E;&EM?5Q%*2\D<'=D)$-O;F9I9WM?9&5L:6U]+SL*"B`@("`D14Y6
M>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*"G-U8B!?<&%R7VEN:71?
M96YV('L*("`@(&EF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I
M('L*("`@("`@("!R971U<FX["B`@("!](&5L<V4@>PH@("`@("`@("1%3E9[
M4$%27TE.251)04Q)6D5$?2`](#(["B`@("!]"@H@("`@9F]R("AQ=R@@4U!!
M5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%($%21T,@05)'
M5E\P("D@*2!["B`@("`@("`@9&5L971E("1%3E9[)U!!4E\G+B1??3L*("`@
M('T*("`@(&9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L*
M("`@("`@("`D14Y6>R=005)?)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,7R<N
M)%]](&EF(&5X:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N)%]].PH@("`@?0H*
M("`@(&UY("1P87)?8VQE86X@/2`B7U]%3E9?4$%27T-,14%.7U\@("`@("`@
M("`@("`@("`B.PH*("`@(&EF("@D14Y6>U!!4E]414U0?2D@>PH@("`@("`@
M(&1E;&5T92`D14Y6>U!!4E]#3$5!3GT["B`@("!]"B`@("!E;'-I9B`H(65X
M:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2!["B`@("`@("`@;7D@)'9A
M;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R("L@;&5N9W1H*")#3$5!3B(I
M*3L*("`@("`@("`D14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L=64@/7X@
M+UY005)?0TQ%04X]*%Q3*RDO.PH@("`@?0I]"@IS=6(@;W5T<R!["B`@("!R
M971U<FX@:68@)'%U:65T.PH@("`@:68@*"1L;V=F:"D@>PH@("`@("`@('!R
M:6YT("1L;V=F:"`B0%]<;B(["B`@("!]"B`@("!E;'-E('L*("`@("`@("!P
M<FEN="`B0%]<;B(["B`@("!]"GT*"G-U8B!I;FET7VEN8R!["B`@("!R97%U
M:7)E($-O;F9I9SL*("`@('!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@
M)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"B`@("`@("`@87)C:&QI8F5X<"!P
M<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*("`@("`@("!V96YD
M;W)A<F-H97AP('9E;F1O<FQI8F5X<`H@("`@*3L*?0H*(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C"B,@5&AE(&UA:6X@<&%C:V%G92!F;W(@<V-R:7!T
M(&5X96-U=&EO;@H*<&%C:V%G92!M86EN.PH*<F5Q=6ER92!005(["G5N<VAI
M9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R
M9W,I.PH*9&EE('%Q*'!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B
M)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN*0H@("`@
M=6YL97-S("UE("1P<F]G;F%M93L*"F1O("1P<F]G;F%M93L*0T]213HZ97AI
M="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`
M(&EF("1`.PH*?3L*"B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0H*0T]213HZ
M97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<
M*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PH*,3L*"B-L:6YE
M(#$P,3$*"E]?14Y$7U\*`````$=#0SH@*$1E8FEA;B`T+C<N,BTU+CDN,C`Q
M-#`S,3(Q-S,Q*2`T+C<N,@!'0T,Z("A$96)I86X@-"XT+C<M,BXX+C(P,30P
M,S$R,30T-2D@-"XT+C<``"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+D%"22UT
M86<`+FYO=&4N9VYU+F)U:6QD+6ED`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS
M='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR96PN9'EN`"YR96PN
M<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`+F5H7V9R86UE7VAD<@`N
M96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?87)R87D`+FIC<@`N9'EN86UI
M8P`N9V]T`"YG;W0N<&QT`"YD871A`"YB<W,`+F-O;6UE;G0`````````````
M``````````````````````````````````````````L````!`````@```#2!
M!`@T`0``$P```````````````0`````````3````!P````(```!(@00(2`$`
M`"````````````````0`````````(0````<````"````:($$"&@!```D````
M```````````$`````````#@````%`````@```(R!!`B,`0``-`,```8`````
M````!`````0````T````]O__;P(```#`A`0(P`0``%@!```&``````````0`
M```$````/@````L````"````&(8$"!@&``"@!@``!P````$````$````$```
M`$8````#`````@```+B,!`BX#```*@4``````````````0````````!.````
M____;P(```#BD00(XA$``-0````&``````````(````"````6P```/[__V\"
M````N)($"+@2``"0````!P````(````$`````````&H````)`````@```$B3
M!`A($P``,`````8`````````!`````@```!S````"0````(```!XDP0(>!,`
M`"`"```&````#0````0````(````?`````$````&````F)4$")@5```F````
M```````````$`````````'<````!````!@```,"5!`C`%0``4`0`````````
M````$`````0```""`````0````8````0F@0($!H``'Q&`````````````!``
M````````B`````$````&````C.`$"(Q@```7```````````````$````````
M`(X````!`````@```*C@!`BH8```2`,`````````````"`````````"6````
M`0````(```#PXP0(\&,``-P```````````````0`````````I`````$````"
M````S.0$",QD``"H!``````````````$`````````*X````.`````P````#P
M!`@`<```!```````````````!`````````"Z````#P````,````$\`0(!'``
M``0```````````````0`````````Q@````$````#````"/`$"`AP```$````
M```````````$`````````,L````&`````P````SP!`@,<```&`$```<`````
M````!`````@```#4`````0````,````D\00()'$```0```````````````0`
M```$````V0````$````#````*/$$""AQ```<`0`````````````$````!```
M`.(````!`````P```&#R!`A@<@``Y%L`````````````(`````````#H````
M"`````,```!@3@4(1,X``'`0`````````````"``````````[0````$````P
M`````````$3.``!6```````````````!`````0````$````#````````````
:``":S@``]@```````````````0``````````
